@@ -1,8 +1,6 @@
-# pylint: skip-file
-# type: ignore
+# pylint: disable=invalid-name
 
 import glob
-import math
 import os
 import typing as _tp
 
@@ -12,25 +10,21 @@ from PyQt5.QtGui import QPixmap, QCursor, QMouseEvent
 from PyQt5.QtWidgets import QGraphicsPixmapItem, QGraphicsTextItem, QMenu, QTreeView
 
 import trnsysGUI.images as _img
-import trnsysGUI.IdGenerator as _id
-from trnsysGUI.MoveCommand import MoveCommand
-from trnsysGUI.PortItem import PortItem
-from trnsysGUI.ResizerItem import ResizerItem
+from trnsysGUI import idGenerator as _id
+from trnsysGUI.MoveCommand import MoveCommand  # type: ignore[attr-defined]
+from trnsysGUI.ResizerItem import ResizerItem  # type: ignore[attr-defined]
+from trnsysGUI.blockItemModel import BlockItemModel
+from trnsysGUI.doublePipePortItem import DoublePipePortItem
+from trnsysGUI.singlePipePortItem import SinglePipePortItem
 
-global FilePath
-FilePath = "res/Config.txt"
-
-
-def calcDist(p1, p2):
-    vec = p1 - p2
-    norm = math.sqrt(vec.x() ** 2 + vec.y() ** 2)
-    return norm
+FILEPATH = "res/Config.txt"
 
 
+# pylint: disable = fixme
 # TODO : TeePiece and AirSourceHp size ratio need to be fixed, maybe just use original
 #  svg instead of modified ones, TVentil is flipped. heatExchangers are also wrongly oriented
-class BlockItem(QGraphicsPixmapItem):
-    def __init__(self, trnsysType, parent, **kwargs):
+class BlockItem(QGraphicsPixmapItem):  # pylint: disable = too-many-public-methods, too-many-instance-attributes
+    def __init__(self, trnsysType, parent, displayNamePrefix=None, displayName=None, **kwargs):
         super().__init__(None)
 
         self.logger = parent.logger
@@ -41,29 +35,24 @@ class BlockItem(QGraphicsPixmapItem):
         self.id = self.parent.parent().idGen.getID()
         self.propertyFile = []
 
-        if "displayName" in kwargs:
-            self.displayName = kwargs["displayName"]
+        if displayNamePrefix:
+            self.displayName = displayNamePrefix + str(self.id)
+        elif displayName:
+            self.displayName = displayName
         else:
-            self.displayName = trnsysType + "_" + str(self.id)
+            raise Exception('No display name defined.')
 
         if "loadedBlock" not in kwargs:
             self.parent.parent().trnsysObj.append(self)
 
-        self.groupName = ""
-        self.setDefaultGroup()
-
         self.inputs = []
         self.outputs = []
 
+        self.path = None
+
         # Export related:
         self.name = trnsysType
         self.trnsysId = self.parent.parent().idGen.getTrnsysID()
-        self.typeNumber = 0
-        self.exportConnsString = ""
-        self.exportInputName = "0"
-        self.exportInitialInput = -1
-        self.exportEquations = []
-        self.trnsysConn = []
 
         # Transform related
         self.flippedV = False
@@ -83,20 +72,6 @@ class BlockItem(QGraphicsPixmapItem):
         self.label = QGraphicsTextItem(self.displayName, self)
         self.label.setVisible(False)
 
-        if self.name == "Bvi":
-            self.inputs.append(PortItem("i", 0, self))
-            self.outputs.append(PortItem("o", 2, self))
-
-        if self.name == "StorageTank":
-            # Inputs get appended in ConfigStorage
-            pass
-
-        self.logger.debug("Block name is " + str(self.name))
-
-        # Update size for generic block:
-        if self.name == "Bvi":
-            self.changeSize()
-
         # Experimental, used for detecting genereated blocks attached to storage ports
         self.inFirstRow = False
 
@@ -107,6 +82,9 @@ class BlockItem(QGraphicsPixmapItem):
         self.origInputsPos = None
 
     def _getImageAccessor(self) -> _tp.Optional[_img.ImageAccessor]:
+        if isinstance(self, BlockItem):
+            raise AssertionError("`BlockItem' cannot be instantiated directly.")
+
         currentClassName = BlockItem.__name__
         currentMethodName = f"{currentClassName}.{BlockItem._getImageAccessor.__name__}"
 
@@ -125,6 +103,12 @@ class BlockItem(QGraphicsPixmapItem):
 
         raise exception
 
+    def addTree(self):
+        pass
+
+    def hasDdckPlaceHolders(self):  # pylint: disable = no-self-use
+        return False
+
     # Setter functions
     def setParent(self, p):
         self.parent = p
@@ -133,51 +117,10 @@ class BlockItem(QGraphicsPixmapItem):
             self.parent.parent().trnsysObj.append(self)
             # self.logger.debug("trnsysObj are " + str(self.parent.parent().trnsysObj))
 
-    def setDefaultGroup(self):
-        """
-        Sets the group to defaultGroup when being created.
-        Returns
-        -------
-
-        """
-        self.setBlockToGroup("defaultGroup")
-
-    def setBlockToGroup(self, newGroupName):
-        """
-        Sets the groupName of this Block to newGroupName and appends itself to the itemList of that group
-        Parameters
-        ----------
-        newGroupName
-
-        Returns
-        -------
-
-        """
-        # self.logger.debug("In setBlockToGroup")
-        if newGroupName == self.groupName:
-            self.logger.debug(
-                "Block "
-                + str(self)
-                + str(self.displayName)
-                + "is already in this group"
-            )
-            return
-        else:
-            # self.logger.debug("groups is " + str(self.parent.parent().groupList))
-            for g in self.parent.parent().groupList:
-                if g.displayName == self.groupName:
-                    self.logger.debug("Found the old group " + self.groupName)
-                    g.itemList.remove(self)
-                if g.displayName == newGroupName:
-                    # self.logger.debug("Found the new group " + newGroupName)
-                    g.itemList.append(self)
-
-            self.groupName = newGroupName
-
     def setId(self, newId):
         self.id = newId
 
-    def setName(self, newName):
+    def setDisplayName(self, newName: str) -> None:
         self.displayName = newName
         self.label.setPlainText(newName)
 
@@ -209,18 +152,19 @@ class BlockItem(QGraphicsPixmapItem):
 
     def launchNotepadFile(self):
         self.logger.debug("Launching notpad")
-        global FilePath
-        os.system("start notepad++ " + FilePath)
+        os.system("start notepad++ " + FILEPATH)
 
-    def mouseDoubleClickEvent(self, event):
+    def mouseDoubleClickEvent(self, event):  # pylint: disable=unused-argument
         if hasattr(self, "isTempering"):
-            dia = self.parent.parent().showTVentilDlg(self)
+            self.parent.parent().showTVentilDlg(self)
         elif self.name == "Pump":
-            dia = self.parent.parent().showPumpDlg(self)
-        elif self.name == "TeePiece" or self.name == "WTap_main":
-            dia = self.parent.parent().showBlockDlg(self)
+            self.parent.parent().showPumpDlg(self)
+        elif self.name in ("TeePiece", "WTap_main"):
+            self.parent.parent().showBlockDlg(self)
+        elif self.name in ["SPCnr", "DPCnr", "DPTee"]:
+            self.parent.parent().showDoublePipeBlockDlg(self)
         else:
-            dia = self.parent.parent().showBlockDlg(self)
+            self.parent.parent().showBlockDlg(self)
             if len(self.propertyFile) > 0:
                 for files in self.propertyFile:
                     os.startfile(files, "open")
@@ -237,39 +181,25 @@ class BlockItem(QGraphicsPixmapItem):
                 self.parent.parent().parent().undoStack.push(command)
                 self.oldPos = self.scenePos()
 
-        super(BlockItem, self).mouseReleaseEvent(event)
+        super().mouseReleaseEvent(event)
 
     # Transform related
     def changeSize(self):
-        w = self.w
-        h = self.h
+        self._positionLabel()
 
-        """ Resize block function """
-        delta = 4
-
-        # Limit the block size:
-        if h < 20:
-            h = 20
-        if w < 40:
-            w = 40
-
-        # center label:
+    def _positionLabel(self):
+        width, height = self._getCappedWithAndHeight()
         rect = self.label.boundingRect()
-        lw, lh = rect.width(), rect.height()
-        lx = (w - lw) / 2
-        self.label.setPos(lx, h)
+        labelWidth = rect.width()
+        labelPosX = (height - labelWidth) / 2
+        self.label.setPos(labelPosX, width)
 
-        if self.name == "Bvi":
-            self.inputs[0].setPos(
-                -2 * delta + 4 * self.flippedH * delta + self.flippedH * w, h / 3
-            )
-            self.outputs[0].setPos(
-                -2 * delta + 4 * self.flippedH * delta + self.flippedH * w, 2 * h / 3
-            )
-            self.inputs[0].side = 0 + 2 * self.flippedH
-            self.outputs[0].side = 0 + 2 * self.flippedH
-
-        return w, h
+    def _getCappedWithAndHeight(self):
+        width = self.w
+        height = self.h
+        height = max(height, 20)
+        width = max(width, 40)
+        return width, height
 
     def updateFlipStateH(self, state):
         self.flippedH = bool(state)
@@ -280,30 +210,28 @@ class BlockItem(QGraphicsPixmapItem):
         self.flippedHInt = 1 if self.flippedH else -1
 
         if self.flippedH:
-            for i in range(0, len(self.inputs)):
-                distanceToMirrorAxis = self.w / 2.0 - self.origInputsPos[i][0]
-                self.inputs[i].setPos(
-                    self.origInputsPos[i][0] + 2.0 * distanceToMirrorAxis,
-                    self.inputs[i].pos().y(),
+            for i, inputPort in enumerate(self.inputs):
+                distanceToMirrorAxis = self.w / 2.0 - self.origInputsPos[i][0]  # pylint:disable=unsubscriptable-object
+                inputPort.setPos(
+                    self.origInputsPos[i][0] + 2.0 * distanceToMirrorAxis,  # pylint: disable = unsubscriptable-object
+                    inputPort.pos().y(),
                 )
 
-            for i in range(0, len(self.outputs)):
-                distanceToMirrorAxis = self.w / 2.0 - self.origOutputsPos[i][0]
-                self.outputs[i].setPos(
-                    self.origOutputsPos[i][0] + 2.0 * distanceToMirrorAxis,
-                    self.outputs[i].pos().y(),
+            for i, outPort in enumerate(self.outputs):
+                distanceToMirrorAxis = self.w / 2.0 - self.origOutputsPos[i][0]  # pylint:disable=unsubscriptable-object
+                outPort.setPos(
+                    self.origOutputsPos[i][0] + 2.0 * distanceToMirrorAxis,  # pylint: disable = unsubscriptable-object
+                    outPort.pos().y(),
                 )
 
         else:
-            for i in range(0, len(self.inputs)):
-                self.inputs[i].setPos(
-                    self.origInputsPos[i][0], self.inputs[i].pos().y()
-                )
+            for i, inputPort in enumerate(self.inputs):
+                inputPort.setPos(self.origInputsPos[i][0],  # pylint: disable = unsubscriptable-object
+                                 inputPort.pos().y())
 
-            for i in range(0, len(self.outputs)):
-                self.outputs[i].setPos(
-                    self.origOutputsPos[i][0], self.outputs[i].pos().y()
-                )
+            for i, outputPort in enumerate(self.outputs):
+                outputPort.setPos(self.origOutputsPos[i][0],  # pylint: disable = unsubscriptable-object
+                                  outputPort.pos().y())
 
     def updateFlipStateV(self, state):
         self.flippedV = bool(state)
@@ -314,34 +242,63 @@ class BlockItem(QGraphicsPixmapItem):
         self.flippedVInt = 1 if self.flippedV else -1
 
         if self.flippedV:
-            for i in range(0, len(self.inputs)):
-                distanceToMirrorAxis = self.h / 2.0 - self.origInputsPos[i][1]
-                self.inputs[i].setPos(
-                    self.inputs[i].pos().x(),
-                    self.origInputsPos[i][1] + 2.0 * distanceToMirrorAxis,
+            for i, inputPort in enumerate(self.inputs):
+                distanceToMirrorAxis = self.h / 2.0 - self.origInputsPos[i][1]  # pylint:disable=unsubscriptable-object
+                inputPort.setPos(
+                    inputPort.pos().x(),
+                    self.origInputsPos[i][1] + 2.0 * distanceToMirrorAxis,  # pylint: disable = unsubscriptable-object
                 )
 
-            for i in range(0, len(self.outputs)):
-                distanceToMirrorAxis = self.h / 2.0 - self.origOutputsPos[i][1]
-                self.outputs[i].setPos(
-                    self.outputs[i].pos().x(),
-                    self.origOutputsPos[i][1] + 2.0 * distanceToMirrorAxis,
+            for i, outputPort in enumerate(self.outputs):
+                distanceToMirrorAxis = self.h / 2.0 - self.origOutputsPos[i][1]  # pylint:disable=unsubscriptable-object
+                outputPort.setPos(
+                    outputPort.pos().x(),
+                    self.origOutputsPos[i][1] + 2.0 * distanceToMirrorAxis,  # pylint: disable = unsubscriptable-object
                 )
 
         else:
-            for i in range(0, len(self.inputs)):
-                self.inputs[i].setPos(
-                    self.inputs[i].pos().x(), self.origInputsPos[i][1]
-                )
+            for i, inputPort in enumerate(self.inputs):
+                inputPort.setPos(inputPort.pos().x(),
+                                 self.origInputsPos[i][1])  # pylint: disable = unsubscriptable-object
 
-            for i in range(0, len(self.outputs)):
-                self.outputs[i].setPos(
-                    self.outputs[i].pos().x(), self.origOutputsPos[i][1]
-                )
+            for i, outputPort in enumerate(self.outputs):
+                outputPort.setPos(outputPort.pos().x(),
+                                  self.origOutputsPos[i][1])  # pylint: disable = unsubscriptable-object
 
-    def updateSide(self, port, n):
+    def updateSidesFlippedH(self):
+        if self.rotationN % 2 == 0:
+            for p in self.inputs:
+                if p.side in (0, 2):
+                    self.updateSide(p, 2)
+            for p in self.outputs:
+                if p.side in (0, 2):
+                    self.updateSide(p, 2)
+        if self.rotationN % 2 == 1:
+            for p in self.inputs:
+                if p.side in (1, 3):
+                    self.updateSide(p, 2)
+            for p in self.outputs:
+                if p.side in (1, 3):
+                    self.updateSide(p, 2)
+
+    def updateSidesFlippedV(self):
+        if self.rotationN % 2 == 1:
+            for p in self.inputs:
+                if p.side in (0, 2):
+                    self.updateSide(p, 2)
+            for p in self.outputs:
+                if p.side in (0, 2):
+                    self.updateSide(p, 2)
+        if self.rotationN % 2 == 0:
+            for p in self.inputs:
+                if p.side in (1, 3):
+                    self.updateSide(p, 2)
+            for p in self.outputs:
+                if p.side in (1, 3):
+                    self.updateSide(p, 2)
+
+    def updateSide(self, port, n):  # pylint: disable=no-self-use
         port.side = (port.side + n) % 4
-        # self.logger.debug("Port side is " + str(port.side))
 
     def rotateBlockCW(self):
         # Rotate block clockwise
@@ -361,6 +318,9 @@ class BlockItem(QGraphicsPixmapItem):
             p.itemChange(27, p.scenePos())
             self.updateSide(p, 1)
 
+        pixmap = self._getPixmap()
+        self.setPixmap(pixmap)
+
     def rotateBlockToN(self, n):
         if n > 0:
             while self.rotationN != n:
@@ -386,9 +346,13 @@ class BlockItem(QGraphicsPixmapItem):
             p.itemChange(27, p.scenePos())
             self.updateSide(p, -1)
 
+        pixmap = self._getPixmap()
+        self.setPixmap(pixmap)
+
     def resetRotation(self):
         self.logger.debug("Resetting rotation...")
         self.setRotation(0)
+        self.label.setRotation(0)
 
         for p in self.inputs:
             p.itemChange(27, p.scenePos())
@@ -402,6 +366,9 @@ class BlockItem(QGraphicsPixmapItem):
 
         self.rotationN = 0
 
+        pixmap = self._getPixmap()
+        self.setPixmap(pixmap)
+
     def printRotation(self):
         self.logger.debug("Rotation is " + str(self.rotationN))
 
@@ -417,40 +384,15 @@ class BlockItem(QGraphicsPixmapItem):
                 p.connectionList[0].deleteConn()
 
     def deleteBlock(self):
-        self.logger.debug(
-            "Block " + str(self) + " is deleting itself (" + self.displayName + ")"
-        )
-        self.deleteConns()
-        # self.logger.debug("self.parent.parent" + str(self.parent.parent()))
         self.parent.parent().trnsysObj.remove(self)
-        self.logger.debug("deleting block " + str(self) + self.displayName)
-        # self.logger.debug("self.scene is" + str(self.parent.scene()))
         self.parent.scene().removeItem(self)
-        widgetToRemove = self.parent.parent().findChild(
-            QTreeView, self.displayName + "Tree"
-        )
-        try:
+        widgetToRemove = self.parent.parent().findChild(QTreeView, self.displayName + "Tree")
+        if widgetToRemove:
             widgetToRemove.hide()
-        except AttributeError:
-            self.logger.debug("Widget doesnt exist!")
-        else:
-            self.logger.debug("Deleted widget")
-        del self
 
     def deleteBlockCom(self):
-        # command = trnsysGUI.DeleteBlockCommand.DeleteBlockCommand(self, "Delete block command")
-        # self.parent.parent().parent().undoStack.push(command)
         self.parent.deleteBlockCom(self)
 
-    def configGroup(self):
-        """
-        This method is called from the contextMenu and allows to pick a group for this block.
-        Returns
-        -------
-
-        """
-        self.parent.parent().showGroupChooserBlockDlg(self)
-
     def getConnections(self):
         """
         Get the connections from inputs and outputs of this block.
@@ -468,7 +410,7 @@ class BlockItem(QGraphicsPixmapItem):
         return c
 
     # Scaling related
-    def mousePressEvent(self, event):  # create resizer
+    def mousePressEvent(self, event):  # pylint: disable = unused-argument
         """
         Using try catch to avoid creating extra resizers.
 
@@ -483,24 +425,20 @@ class BlockItem(QGraphicsPixmapItem):
 
         """
         self.logger.debug("Inside Block Item mouse click")
-        if self.name == "GenericBlock" or self.name == "StorageTank":
+
+        self.isSelected = True
+        if self.name in ("GenericBlock", "StorageTank"):
             return
         try:
             self.resizer
         except AttributeError:
-            self.resizer = ResizerItem(self)
+            self.resizer = ResizerItem(self)  # pylint: disable = attribute-defined-outside-init
             self.resizer.setPos(self.w, self.h)
             self.resizer.itemChange(self.resizer.ItemPositionChange, self.resizer.pos())
-        else:
-            return
 
     def setItemSize(self, w, h):
         self.logger.debug("Inside block item set item size")
         self.w, self.h = w, h
-        # if h < 20:
-        #     self.h = 20
-        # if w < 40:
-        #     self.w = 40
 
     def updateImage(self):
         self.logger.debug("Inside block item update image")
@@ -515,7 +453,9 @@ class BlockItem(QGraphicsPixmapItem):
             self.updateFlipStateV(self.flippedV)
 
     def _getPixmap(self) -> QPixmap:
-        imageAccessor = self._getImageAccessor()
+        imageAccessor = self._getImageAccessor()  # pylint: disable = assignment-from-no-return
+
+        assert imageAccessor
 
         image = imageAccessor.image(width=self.w, height=self.h).mirrored(
             horizontal=self.flippedH, vertical=self.flippedV
@@ -532,49 +472,8 @@ class BlockItem(QGraphicsPixmapItem):
         else:
             del self.resizer
 
-    # Debug
-    def dumpBlockInfo(self):
-        # for a in inspect.getMembers(self):
-        #     self.logger.debug(str(a))
-
-        self.logger.debug("This is a dump of " + str(self))
-        self.logger.debug("Name = " + str(self.displayName))
-        self.logger.debug("TrnsysType = " + str(self.name))
-        self.logger.debug("TrnsysTypeNumber = " + str(self.typeNumber))
-        self.logger.debug("Size = " + str(self.w) + " * " + str(self.h))
-
-        self.printIds()
-        self.printConnections()
-
-    def printIds(self):
-        self.logger.debug("ID:" + str(self.id))
-        self.logger.debug("TrnsysID: " + str(self.trnsysId))
-
-        for inp in self.inputs:
-            self.logger.debug("Has input with ID " + str(inp.id))
-
-        for out in self.outputs:
-            self.logger.debug("Has output with ID " + str(out.id))
-
-    def printConnections(self):
-        self.logger.debug("Connections are:")
-        for c in self.getConnections():
-            self.logger.debug(c.displayName + " with ID " + str(c.id))
-
-    def inspectBlock(self):
-        self.parent.parent().listV.clear()
-        self.parent.parent().listV.addItem("Name: " + self.name)
-        self.parent.parent().listV.addItem("Display name: " + self.displayName)
-        self.parent.parent().listV.addItem("Group name: " + self.groupName)
-        self.parent.parent().listV.addItem("Parent: " + str(self.parent))
-        self.parent.parent().listV.addItem("Position: " + str(self.pos()))
-        self.parent.parent().listV.addItem("Sceneposition: " + str(self.scenePos()))
-        self.parent.parent().listV.addItem("Inputs: " + str(self.inputs))
-        self.parent.parent().listV.addItem("Outputs: " + str(self.outputs))
-
     # AlignMode related
     def itemChange(self, change, value):
-        # self.logger.debug(change, value)
         # Snap grid excludes alignment
 
         if change == self.ItemPositionChange:
@@ -582,23 +481,13 @@ class BlockItem(QGraphicsPixmapItem):
                 snapSize = self.parent.parent().snapSize
                 self.logger.debug("itemchange")
                 self.logger.debug(type(value))
-                value = QPointF(
-                    value.x() - value.x() % snapSize, value.y() - value.y() % snapSize
-                )
+                value = QPointF(value.x() - value.x() % snapSize, value.y() - value.y() % snapSize)
                 return value
-            else:
-                # if self.hasElementsInYBand() and not self.elementInY() and not self.aligned:
-                if self.parent.parent().alignMode:
-                    if self.hasElementsInYBand():
-                        return self.alignBlock(value)
-                    else:
-                        # self.aligned = False
-                        return value
-
-                else:
-                    return value
-        else:
-            return super(BlockItem, self).itemChange(change, value)
+            if self.parent.parent().alignMode:
+                if self.hasElementsInYBand():
+                    return self.alignBlock(value)
+            return value
+        return super().itemChange(change, value)
 
     def alignBlock(self, value):
         for t in self.parent.parent().trnsysObj:
@@ -606,10 +495,7 @@ class BlockItem(QGraphicsPixmapItem):
                 if self.elementInYBand(t):
                     value = QPointF(self.pos().x(), t.pos().y())
                     self.parent.parent().alignYLineItem.setLine(
-                        self.pos().x() + self.w / 2,
-                        t.pos().y(),
-                        t.pos().x() + t.w / 2,
-                        t.pos().y(),
+                        self.pos().x() + self.w / 2, t.pos().y(), t.pos().x() + t.w / 2, t.pos().y()
                     )
 
                     self.parent.parent().alignYLineItem.setVisible(True)
@@ -628,16 +514,11 @@ class BlockItem(QGraphicsPixmapItem):
                     )
                     self.parent.mouseReleaseEvent(e)
                     self.parent.parent().alignMode = False
-                    # self.setPos(self.pos().x(), t.pos().y())
-                    # self.aligned = True
 
                 if self.elementInXBand(t):
                     value = QPointF(t.pos().x(), self.pos().y())
                     self.parent.parent().alignXLineItem.setLine(
-                        t.pos().x(),
-                        t.pos().y() + self.w / 2,
-                        t.pos().x(),
-                        self.pos().y() + t.w / 2,
+                        t.pos().x(), t.pos().y() + self.w / 2, t.pos().x(), self.pos().y() + t.w / 2
                     )
 
                     self.parent.parent().alignXLineItem.setVisible(True)
@@ -683,15 +564,11 @@ class BlockItem(QGraphicsPixmapItem):
 
     def elementInYBand(self, t):
         eps = 50
-        return (
-            self.scenePos().y() - eps <= t.scenePos().y() <= self.scenePos().y() + eps
-        )
+        return self.scenePos().y() - eps <= t.scenePos().y() <= self.scenePos().y() + eps
 
     def elementInXBand(self, t):
         eps = 50
-        return (
-            self.scenePos().x() - eps <= t.scenePos().x() <= self.scenePos().x() + eps
-        )
+        return self.scenePos().x() - eps <= t.scenePos().x() <= self.scenePos().x() + eps
 
     def elementInY(self):
         for t in self.parent.parent().trnsysObj:
@@ -700,66 +577,60 @@ class BlockItem(QGraphicsPixmapItem):
                     return True
         return False
 
-    # Encoding
     def encode(self):
-        # Double check that no virtual block gets encoded
-        if self.isVisible():
-            portListInputs = []
-            portListOutputs = []
+        portListInputs = []
+        portListOutputs = []
 
-            for p in self.inputs:
-                portListInputs.append(p.id)
-            for p in self.outputs:
-                portListOutputs.append(p.id)
-            dct = {}
+        for inp in self.inputs:
+            portListInputs.append(inp.id)
+        for output in self.outputs:
+            portListOutputs.append(output.id)
 
-            dct[".__BlockDict__"] = True
-            dct["BlockName"] = self.name
-            dct["BlockDisplayName"] = self.displayName
-            dct["BlockPosition"] = (float(self.pos().x()), float(self.pos().y()))
-            dct["ID"] = self.id
-            dct["trnsysID"] = self.trnsysId
-            dct["PortsIDIn"] = portListInputs
-            dct["PortsIDOut"] = portListOutputs
-            dct["FlippedH"] = self.flippedH
-            dct["FlippedV"] = self.flippedV
-            dct["RotationN"] = self.rotationN
-            dct["GroupName"] = self.groupName
+        blockPosition = (float(self.pos().x()), float(self.pos().y()))
 
-            dictName = "Block-"
+        blockItemModel = BlockItemModel(
+            self.name,
+            self.displayName,
+            blockPosition,
+            self.id,
+            self.trnsysId,
+            portListInputs,  # pylint: disable = duplicate-code # 1
+            portListOutputs,
+            self.flippedH,
+            self.flippedV,
+            self.rotationN,
+        )
 
-            return dictName, dct
+        dictName = "Block-"
+        return dictName, blockItemModel.to_dict()
 
     def decode(self, i, resBlockList):
-        self.setPos(float(i["BlockPosition"][0]), float(i["BlockPosition"][1]))
-        self.trnsysId = i["trnsysID"]
-        self.id = i["ID"]
-        self.updateFlipStateH(i["FlippedH"])
-        self.updateFlipStateV(i["FlippedV"])
-        self.rotateBlockToN(i["RotationN"])
-        self.setName(i["BlockDisplayName"])
+        model = BlockItemModel.from_dict(i)
 
-        self.groupName = "defaultGroup"
-        self.setBlockToGroup(i["GroupName"])
+        self.setDisplayName(model.BlockDisplayName)
+        self.setPos(float(model.blockPosition[0]), float(model.blockPosition[1]))
+        self.id = model.Id
+        self.trnsysId = model.trnsysId
 
-        self.logger.debug(len(self.inputs))
+        if len(self.inputs) != len(model.portsIdsIn) or len(self.outputs) != len(model.portsIdsOut):
+            temp = model.portsIdsIn
+            model.portsIdsIn = model.portsIdsOut
+            model.portsIdsOut = temp
 
-        if len(self.inputs) != len(i["PortsIDIn"]) or len(self.outputs) != len(
-            i["PortsIDOut"]
-        ):
-            temp = i["PortsIDIn"]
-            i["PortsIDIn"] = i["PortsIDOut"]
-            i["PortsIDOut"] = temp
+        for index, inp in enumerate(self.inputs):
+            inp.id = model.portsIdsIn[index]
 
-        for x in range(len(self.inputs)):
-            self.inputs[x].id = i["PortsIDIn"][x]
+        for index, out in enumerate(self.outputs):
+            out.id = model.portsIdsOut[index]
 
-        for x in range(len(self.outputs)):
-            self.outputs[x].id = i["PortsIDOut"][x]
+        self.updateFlipStateH(model.flippedH)
+        self.updateFlipStateV(model.flippedV)
+        self.rotateBlockToN(model.rotationN)
 
         resBlockList.append(self)
 
-    def decodePaste(self, i, offset_x, offset_y, resConnList, resBlockList, **kwargs):
+    def decodePaste(self, i, offset_x, offset_y, resConnList, resBlockList,
+                    **kwargs):  # pylint: disable=unused-argument
         self.setPos(
             float(i["BlockPosition"][0] + offset_x),
             float(i["BlockPosition"][1] + offset_y),
@@ -769,33 +640,33 @@ class BlockItem(QGraphicsPixmapItem):
         self.updateFlipStateV(i["FlippedV"])
         self.rotateBlockToN(i["RotationN"])
 
-        for x in range(len(self.inputs)):
-            self.inputs[x].id = i["PortsIDIn"][x]
+        for x, inputPort in enumerate(self.inputs):
+            inputPort.id = i["PortsIDIn"][x]
 
-        for x in range(len(self.outputs)):
-            self.outputs[x].id = i["PortsIDOut"][x]
+        for x, outputPort in enumerate(self.outputs):
+            outputPort.id = i["PortsIDOut"][x]
 
         resBlockList.append(self)
 
     # Export related
     def exportBlackBox(self):
         equation = []
-        if len(self.inputs + self.outputs) == 2 and self.isVisible():
+        if (
+                len(self.inputs + self.outputs) == 2
+                and self.isVisible()
+                and not isinstance(self.outputs[0], DoublePipePortItem)
+        ):
             files = glob.glob(os.path.join(self.path, "**/*.ddck"), recursive=True)
-            if not (files):
+            if not files:
                 status = "noDdckFile"
             else:
                 status = "noDdckEntry"
             lines = []
             for file in files:
-                infile = open(file, "r")
-                lines += infile.readlines()
-            for i in range(len(lines)):
-                if (
-                    "output" in lines[i].lower()
-                    and "to" in lines[i].lower()
-                    and "hydraulic" in lines[i].lower()
-                ):
+                with open(file, "r") as infile:  # pylint: disable=unspecified-encoding
+                    lines += infile.readlines()
+            for i, line in enumerate(lines):
+                if "output" in line.lower() and "to" in line.lower() and "hydraulic" in line.lower():
                     for j in range(i, len(lines) - i):
                         if lines[j][0] == "T":
                             outputT = lines[j].split("=")[0].replace(" ", "")
@@ -806,85 +677,35 @@ class BlockItem(QGraphicsPixmapItem):
         else:
             status = "noBlackBoxOutput"
 
-        if status == "noDdckFile" or status == "noDdckEntry":
+        if status in ("noDdckFile", "noDdckEntry"):
             equation.append("T" + self.displayName + "=1")
 
         return status, equation
 
-    def exportPumpOutlets(self):
+    def exportPumpOutlets(self):  # pylint: disable=no-self-use
         return "", 0
 
-    def exportMassFlows(self):
+    def exportMassFlows(self):  # pylint: disable=no-self-use
         return "", 0
 
-    def exportDivSetting1(self):
+    def exportDivSetting1(self):  # pylint: disable=no-self-use
         return "", 0
 
-    def exportDivSetting2(self, nUnit):
+    def exportDivSetting2(self, nUnit):  # pylint: disable=no-self-use
         return "", nUnit
 
-    def exportParametersFlowSolver(self, descConnLength):
-        temp = ""
-        for i in self.inputs:
-            for c in i.connectionList:
-                temp = temp + str(c.trnsysId) + " "
-                self.trnsysConn.append(c)
-
-        for o in self.outputs:
-            for c in o.connectionList:
-                temp = temp + str(c.trnsysId) + " "
-                self.trnsysConn.append(c)
-
-        temp += "0 "
-        temp += str(self.typeNumber)
-        temp += " " * (descConnLength - len(temp))
-        self.exportConnsString = temp
-
-        f = temp + "!" + str(self.trnsysId) + " : " + str(self.displayName) + "\n"
-
-        return f
-
-    def exportInputsFlowSolver1(self):
-        return "0,0 ", 1
-
-    def exportInputsFlowSolver2(self):
-        return str(self.exportInitialInput) + " ", 1
-
-    def exportOutputsFlowSolver(self, prefix, abc, equationNumber, simulationUnit):
-        equation1 = self._createFlowSolverOutputEquation(0, abc, prefix, equationNumber, simulationUnit)
-        equation2 = self._createFlowSolverOutputEquation(1, abc, prefix, equationNumber, simulationUnit)
-
-        self.exportEquations.append(equation1)
-        self.exportEquations.append(equation2)
-
-        equations = equation1 + equation2
-        nEquationsUsed = 2
-        nextEquationNumber = equationNumber + 3
-
-        return equations, nextEquationNumber, nEquationsUsed
-
-    def _createFlowSolverOutputEquation(self, equationNumber, abc, prefix, equationNumberOffset, simulationUnit):
-        return f"{prefix}{self.displayName}_{abc[equationNumber]}=[{simulationUnit},{equationNumberOffset + equationNumber}]\n"
-
-    def exportPipeAndTeeTypesForTemp(self, startingUnit):
+    def exportPipeAndTeeTypesForTemp(self, startingUnit: int) -> _tp.Tuple[str, int]:  # pylint: disable=no-self-use
         return "", startingUnit
 
-    def getTemperatureVariableName(self, portItem: PortItem) -> str:
+    def getTemperatureVariableName(self, portItem: SinglePipePortItem) -> str:  # pylint: disable=unused-argument
         return f"T{self.displayName}"
 
-    def getFlowSolverParametersId(self, portItem: PortItem) -> int:
+    def getFlowSolverParametersId(self, portItem: SinglePipePortItem) -> int:  # pylint: disable=unused-argument
         return self.trnsysId
 
     def assignIDsToUninitializedValuesAfterJsonFormatMigration(self, generator: _id.IdGenerator) -> None:
         pass
 
-    def cleanUpAfterTrnsysExport(self):
-        self.exportConnsString = ""
-        self.exportInputName = "0"
-        # self.exportInitialInput = -1
-        self.exportEquations = []
-        self.trnsysConn = []
-
     def deleteLoadedFile(self):
         for items in self.loadedFiles:
             try:
