@@ -5,28 +5,35 @@ import os
 import shutil
 import typing as _tp
 
-from PyQt5.QtCore import QSize
-from PyQt5.QtGui import QPixmap
 from PyQt5.QtWidgets import QTreeView
 
+import trnsysGUI.createSinglePipePortItem as _cspi
+import trnsysGUI.images as _img
+import trnsysGUI.massFlowSolver.networkModel as _mfn
 from trnsysGUI.BlockItem import BlockItem
 from trnsysGUI.MyQFileSystemModel import MyQFileSystemModel
 from trnsysGUI.MyQTreeView import MyQTreeView
-from trnsysGUI.PortItem import PortItem
-import trnsysGUI.images as _img
+from trnsysGUI.massFlowSolver import InternalPiping, MassFlowNetworkContributorMixin
 
 
-class Collector(BlockItem):
+class Collector(BlockItem, MassFlowNetworkContributorMixin):
     def __init__(self, trnsysType, parent, **kwargs):
         super().__init__(trnsysType, parent, **kwargs)
 
-        self.inputs.append(PortItem("i", 2, self))
-        self.outputs.append(PortItem("o", 2, self))
+        self.inputs.append(_cspi.createSinglePipePortItem("i", 2, self))
+        self.outputs.append(_cspi.createSinglePipePortItem("o", 2, self))
         self.loadedFiles = []
 
         self.changeSize()
         self.addTree()
 
+    def getInternalPiping(self) -> InternalPiping:
+        inputPort = _mfn.PortItem("input", _mfn.PortItemType.INPUT)
+        outputPort = _mfn.PortItem("output", _mfn.PortItemType.OUTPUT)
+        pipe = _mfn.Pipe(self.displayName, self.trnsysId, inputPort, outputPort)
+
+        return InternalPiping([pipe], {inputPort: self.inputs[0], outputPort: self.outputs[0]})
+
     def _getImageAccessor(self) -> _tp.Optional[_img.ImageAccessor]:
         return _img.COLLECTOR_SVG
 
@@ -65,18 +72,12 @@ class Collector(BlockItem):
         When a blockitem is added to the main window.
         A file explorer for that item is added to the right of the main window by calling this method
         """
-        self.logger.debug(self.parent.parent())
-        # pathName = 'Collector_' + self.displayName
-        pathName = self.displayName
         if self.parent.parent().projectPath == "":
-            # self.path = os.path.dirname(__file__)
-            # self.path = os.path.join(self.path, 'default')
             self.path = self.parent.parent().projectFolder
-            # now = datetime.now()
-            # self.fileName = now.strftime("%Y%m%d%H%M%S")
-            # self.path = os.path.join(self.path, self.fileName)
         else:
             self.path = self.parent.parent().projectPath
+
+        pathName = self.displayName
         self.path = os.path.join(self.path, "ddck")
         self.path = os.path.join(self.path, pathName)
         if not os.path.exists(self.path):
@@ -95,28 +96,8 @@ class Collector(BlockItem):
         self.tree.setSortingEnabled(True)
         self.parent.parent().splitter.addWidget(self.tree)
 
-    # def loadFile(self, file):
-    #     filePath = self.parent.parent().projectPath
-    #     msgB = QMessageBox()
-    #     if filePath == '':
-    #         msgB.setText("Please select a project path before loading!")
-    #         msgB.exec_()
-    #     else:
-    #         self.logger.debug("file loaded into %s" % filePath)
-    #         shutil.copy(file, filePath)
-
-    def updateTreePath(self, path):
-        """
-        When the user chooses the project path for the file explorers, this method is called
-        to update the root path.
-        """
-        pathName = self.displayName
-        self.path = os.path.join(path, "ddck")
-        self.path = os.path.join(self.path, pathName)
-        if not os.path.exists(self.path):
-            os.makedirs(self.path)
-        self.model.setRootPath(self.path)
-        self.tree.setRootIndex(self.model.index(self.path))
+    def hasDdckPlaceHolders(self):
+        return True
 
     def deleteBlock(self):
         """
@@ -124,10 +105,8 @@ class Collector(BlockItem):
         """
         self.logger.debug("Block " + str(self) + " is deleting itself (" + self.displayName + ")")
         self.deleteConns()
-        # self.logger.debug("self.parent.parent" + str(self.parent.parent()))
         self.parent.parent().trnsysObj.remove(self)
         self.logger.debug("deleting block " + str(self) + self.displayName)
-        # self.logger.debug("self.scene is" + str(self.parent.scene()))
         self.parent.scene().removeItem(self)
         widgetToRemove = self.parent.parent().findChild(QTreeView, self.displayName + "Tree")
         try:
@@ -143,7 +122,7 @@ class Collector(BlockItem):
             self.logger.debug("Deleted widget")
         del self
 
-    def setName(self, newName):
+    def setDisplayName(self, newName):
         """
         Overridden method to also change folder name
         """
@@ -152,27 +131,8 @@ class Collector(BlockItem):
         self.model.setName(self.displayName)
         self.tree.setObjectName("%sTree" % self.displayName)
         self.logger.debug(os.path.dirname(self.path))
-        # destPath = str(os.path.dirname(self.path))+'\\Collector_'+self.displayName
         destPath = os.path.join(os.path.split(self.path)[0], self.displayName)
         if os.path.exists(self.path):
             os.rename(self.path, destPath)
             self.path = destPath
             self.logger.debug(self.path)
-
-    # def exportBlackBox(self):
-    #     equation = []
-    #     if len(self.inputs + self.outputs) == 2 and self.isVisible():
-    #         files = glob.glob(os.path.join(self.path, "**/*.ddck"), recursive=True)
-    #         lines = []
-    #         for file in files:
-    #             infile = open(file, 'r')
-    #             lines += infile.readlines()
-    #         for i in range(len(lines)):
-    #             if 'output' in lines[i].lower() and 'to' in lines[i].lower() and 'hydraulic' in lines[i].lower():
-    #                 for j in range(i, len(lines) - i):
-    #                     if lines[j][0] == "T":
-    #                         outputT = lines[j].split("=")[0].replace(" ", "")
-    #                         break
-    #                 break
-    #         equation = ["T" + self.displayName + "=" + outputT + "\n"]
-    #     return equation
