@@ -7,27 +7,27 @@ import shutil
 import subprocess
 import sys
 
+import pkg_resources
 from PyQt5.QtWidgets import *
-from pytrnsys.utils import log
 
+import pytrnsys.utils.result as _res
 import trnsysGUI.arguments as args
-import trnsysGUI.buildDck as dckBuilder
+import trnsysGUI.buildDck as buildDck
 import trnsysGUI.common.cancelled as _ccl
-import trnsysGUI.common.error as _err
 import trnsysGUI.diagram.Editor as _de
 import trnsysGUI.images as _img
 import trnsysGUI.project as _prj
 import trnsysGUI.settings as _settings
 import trnsysGUI.settingsDlg as _sdlg
 import trnsysGUI.tracing as trc
+from pytrnsys.utils import log
 from trnsysGUI.BlockItem import BlockItem
-from trnsysGUI.Connection import Connection
-from trnsysGUI.Graphicaltem import GraphicalItem
 from trnsysGUI.MassFlowVisualizer import MassFlowVisualizer
 from trnsysGUI.ProcessMain import ProcessMain
 from trnsysGUI.RunMain import RunMain
-from trnsysGUI.StorageTank import StorageTank
 from trnsysGUI.configFile import configFile
+from trnsysGUI.errors import showErrorMessageBox
+from trnsysGUI.storageTank.widget import StorageTank
 
 __version__ = "1.0.0"
 __author__ = "Stefano Marti"
@@ -35,7 +35,7 @@ __email__ = "stefano.marti@spf.ch"
 __status__ = "Prototype"
 
 
-class _MainWindow(QMainWindow):
+class MainWindow(QMainWindow):
     def __init__(self, logger, project: _prj.Project, parent=None):
         super().__init__(parent)
 
@@ -99,13 +99,6 @@ class _MainWindow(QMainWindow):
         exportDckAction = QAction(_img.EXPORT_DCK_PNG.icon(), "Export dck", self)
         exportDckAction.triggered.connect(self.exportDck)
 
-        editGroupsAction = QAction("Edit groups/loops", self)
-        editGroupsAction.triggered.connect(self.editGroups)
-
-        selectMultipleAction = QAction("Select multiple items", self)
-        selectMultipleAction.triggered.connect(self.createSelection)
-        selectMultipleAction.setShortcut("s")
-
         toggleSnapAction = QAction("Toggle snap grid", self)
         toggleSnapAction.triggered.connect(self.toggleSnap)
         toggleSnapAction.setShortcut("a")
@@ -124,15 +117,6 @@ class _MainWindow(QMainWindow):
         )
         openVisualizerAction.triggered.connect(self.visualizeMf)
 
-        trnsysList = QAction("Print trnsysObj", self)
-        trnsysList.triggered.connect(self.mb_debug)
-
-        loadVisual = QAction("Load MRF", self)
-        loadVisual.triggered.connect(self.loadVisualization)
-
-        runAction = QAction(_img.ROTATE_TO_RIGHT_PNG.icon(), "Run", self)
-        runAction.triggered.connect(self.runApp)
-
         # Tool bar
         tb = self.addToolBar("Main Toolbar...")
         tb.setObjectName("Toolbar")
@@ -182,31 +166,66 @@ class _MainWindow(QMainWindow):
         debugConnections.triggered.connect(self.debugConns)
         self.fileMenu.addAction(debugConnections)
 
+        def askForSaveAndLoadSettings() -> None:
+            self.askUserForSettingsValuesAndSave()
+            self.loadTrnsysPath()
+
         setTransysPath = QAction("Set TRNSYS path", self)
-        setTransysPath.triggered.connect(self.askUserForSettingsValuesAndSave)
+        setTransysPath.triggered.connect(askForSaveAndLoadSettings)
         self.fileMenu.addAction(setTransysPath)
 
         self.editMenu = QMenu("Edit")
         self.editMenu.addAction(toggleSnapAction)
         self.editMenu.addAction(toggleAlignModeAction)
 
-        AboutAction = QAction("About", self)
-        AboutAction.triggered.connect(self.showAbout)
+        runMassflowSolverActionMenu = QAction("Run mass flow solver", self)
+        runMassflowSolverActionMenu.triggered.connect(self.runAndVisMf)
 
-        VersionAction = QAction("Version", self)
-        VersionAction.triggered.connect(self.showVersion)
+        openVisualizerActionMenu = QAction("Start mass flow visualizer", self)
+        openVisualizerActionMenu.triggered.connect(self.visualizeMf)
 
-        CreditsAction = QAction("Credits", self)
-        CreditsAction.triggered.connect(self.showCredits)
+        exportHydraulicsActionMenu = QAction("Export hydraulic.ddck", self)
+        exportHydraulicsActionMenu.triggered.connect(self.exportHydraulicsDdck)
+
+        exportHydCtrlActionMenu = QAction("Export hydraulic_control.ddck", self)
+        exportHydCtrlActionMenu.triggered.connect(self.exportHydraulicControl)
+
+        updateConfigActionMenu = QAction("Update run.config", self)
+        updateConfigActionMenu.triggered.connect(self.updateRun)
+
+        exportDckActionMenu = QAction("Export dck", self)
+        exportDckActionMenu.triggered.connect(self.exportDck)
+
+        runSimulationActionMenu = QAction("Run simulation...", self)
+        runSimulationActionMenu.triggered.connect(self.runSimulation)
+
+        processSimulationActionMenu = QAction("Process simulation...", self)
+        processSimulationActionMenu.triggered.connect(self.processSimulation)
+
+        exportDdckPlaceHolderValuesJsonFileActionMenu = QAction("Export json-file containing connection information", self)
+        exportDdckPlaceHolderValuesJsonFileActionMenu.triggered.connect(self.exportDdckPlaceHolderValuesJson)
+
+        self.projectMenu = QMenu("Project")
+        self.projectMenu.addAction(runMassflowSolverActionMenu)
+        self.projectMenu.addAction(openVisualizerActionMenu)
+        self.projectMenu.addAction(exportHydraulicsActionMenu)
+        self.projectMenu.addAction(exportHydCtrlActionMenu)
+        self.projectMenu.addAction(updateConfigActionMenu)
+        self.projectMenu.addAction(exportDckActionMenu)
+        self.projectMenu.addAction(runSimulationActionMenu)
+        self.projectMenu.addAction(processSimulationActionMenu)
+        self.projectMenu.addAction(exportDdckPlaceHolderValuesJsonFileActionMenu)
+
+        pytrnsysOnlineDocAction = QAction("pytrnsys online documentation", self)
+        pytrnsysOnlineDocAction.triggered.connect(self.openPytrnsysOnlineDoc)
 
         self.helpMenu = QMenu("Help")
-        self.helpMenu.addAction(AboutAction)
-        self.helpMenu.addAction(VersionAction)
-        self.helpMenu.addAction(CreditsAction)
+        self.helpMenu.addAction(pytrnsysOnlineDocAction)
 
         # Menu bar
         self.mb = self.menuBar()
         self.mb.addMenu(self.fileMenu)
+        self.mb.addMenu(self.projectMenu)
         self.mb.addMenu(self.editMenu)
         self.mb.addMenu(self.helpMenu)
         self.mb.addSeparator()
@@ -264,6 +283,9 @@ class _MainWindow(QMainWindow):
 
         oldProjectFolderPath = _pl.Path(self.projectFolder)
 
+        self.copyContentsToNewFolder(newProjectFolderPath, oldProjectFolderPath)
+
+    def copyContentsToNewFolder(self, newProjectFolderPath, oldProjectFolderPath):
         self._copyContents(oldProjectFolderPath, newProjectFolderPath)
         newJsonFilePath = self._changeAndGetNewJsonFileName(newProjectFolderPath, oldProjectFolderPath)
 
@@ -350,15 +372,11 @@ class _MainWindow(QMainWindow):
                     storageWithoutFile.append(object.displayName + "\n")
 
         if storageWithoutFile:
-            messageText = "The following storage tank(s) do(es) not have a corresponding ddck:\n\n"
+            errorMessage = "The following storage tank(s) do(es) not have a corresponding ddck:\n\n"
             for storage in storageWithoutFile:
-                messageText += storage
-            messageText += "\nPlease make sure you that you export the ddck for every storage tank before starting a simulation."
-            qmb = QMessageBox()
-            qmb.setText(messageText)
-            qmb.setStandardButtons(QMessageBox.Ok)
-            qmb.setDefaultButton(QMessageBox.Ok)
-            qmb.exec()
+                errorMessage += storage
+            errorMessage += "\nPlease make sure you that you export the ddck for every storage tank before starting a simulation."
+            showErrorMessageBox(errorMessage)
             return
 
         #   Update run.config
@@ -371,27 +389,18 @@ class _MainWindow(QMainWindow):
         )
 
         if executionFailed:
-            messageText = (
-                "Exception while trying to execute RunParallelTrnsys:\n\n"
-                + errorStatement
+            errorMessage = (
+                f"Exception while trying to execute RunParallelTrnsys:\n\n{errorStatement}"
             )
-            qmb = QMessageBox()
-            qmb.setText(messageText)
-            qmb.setStandardButtons(QMessageBox.Ok)
-            qmb.setDefaultButton(QMessageBox.Ok)
-            qmb.exec()
+            showErrorMessageBox(errorMessage)
 
         return
 
     def processSimulation(self):
         processPath = os.path.join(self.projectFolder, "process.config")
         if not os.path.isfile(processPath):
-            messageText = "No such file:\n" + processPath
-            qmb = QMessageBox()
-            qmb.setText(messageText)
-            qmb.setStandardButtons(QMessageBox.Ok)
-            qmb.setDefaultButton(QMessageBox.Ok)
-            qmb.exec()
+            errorMessage = f"No such file: {processPath}"
+            showErrorMessageBox(errorMessage)
             return
         processApp = ProcessMain()
         executionFailed, errorStatement = processApp.processAction(
@@ -399,18 +408,19 @@ class _MainWindow(QMainWindow):
         )
 
         if executionFailed:
-            messageText = (
-                "Exception while trying to execute RunParallelTrnsys:\n\n"
-                + errorStatement
+            errorMessage = (
+                f"Exception while trying to execute RunParallelTrnsys:\n\n{errorStatement}"
             )
-            qmb = QMessageBox()
-            qmb.setText(messageText)
-            qmb.setStandardButtons(QMessageBox.Ok)
-            qmb.setDefaultButton(QMessageBox.Ok)
-            qmb.exec()
+            showErrorMessageBox(errorMessage)
 
         return
 
+    def exportDdckPlaceHolderValuesJson(self):
+        result = self.centralWidget.exportDdckPlaceHolderValuesJsonFile()
+        if _res.isError(result):
+            errorMessage = f"The json file could not be generated: {result.message}"
+            showErrorMessageBox(errorMessage)
+
     def renameDia(self):
         self.logger.info("Renaming diagram...")
         self.centralWidget.showDiagramDlg()
@@ -430,14 +440,6 @@ class _MainWindow(QMainWindow):
             self.logger.info("Canceling")
             return
 
-    def createGroup(self):
-        # print("Tb createGroup pressed")
-        # global selectionMode
-        self.centralWidget.selectionMode = True
-        self.centralWidget.groupMode = True
-        self.centralWidget.copyMode = False
-        self.centralWidget.multipleSelectMode = False
-
     def tidyUp(self):
         self.logger.info("Tidying up...")
         self.centralWidget.cleanUpConnections()
@@ -454,63 +456,6 @@ class _MainWindow(QMainWindow):
         self.logger.info("Setting zoom 0")
         self.centralWidget.diagramView.resetTransform()
 
-    def copySelection(self):
-        self.logger.info("Copying selection")
-        # global selectionMode
-        # global copyMode
-
-        self.centralWidget.selectionMode = True
-        self.centralWidget.copyMode = True
-        self.centralWidget.groupMode = False
-        self.centralWidget.multipleSelectMode = False
-
-        self.centralWidget.copyElements()
-
-    def pasteSelection(self):
-        self.logger.info("Pasting selection")
-        self.centralWidget.pasteFromClipBoard()
-        # global copyMode
-        self.centralWidget.copyMode = False
-
-    def editGroups(self):
-        self.centralWidget.editGroups()
-
-    def mb_debug(self):
-        pass
-        # print(self.centralWidget.trnsysObj)
-        # a = [int(s.id) for s in self.centralWidget.trnsysObj]
-        # a.sort()
-        # print(a)
-        #
-        # for s in self.centralWidget.trnsysObj:
-        #     if s.id == 11:
-        #         print("Duplicate id obj is " + str(s.displayName) + " " + str(s.id))
-        #
-        # for t in self.centralWidget.trnsysObj:
-        #     t.alignMode = True
-        #     print(t.alignMode)
-
-        # temp = []
-        # for t in self.centralWidget.trnsysObj:
-        #     if isinstance(t, BlockItem):
-        #         for p in t.inputs + t.outputs:
-        #             if p not in temp:
-        #                 temp.append(p)
-        #
-        # for p in temp:
-        #     if p.isFromHx:
-        #         print("Port with parent " + str(p.parent.displayName) + "is from Hx")
-        #
-        # res = True
-        #
-        # for b in self.centralWidget.trnsysObj:
-        #     if isinstance(b, Connection) and b not in self.centralWidget.connectionList:
-        #         res = False
-        #
-        # print("editor connectionList is consistent with trnsysObj: " + str(res))
-
-        # dIns = DeepInspector(self.centralWidget)
-
     def runAndVisMf(self):
         self.calledByVisualizeMf = True
         filePaths = self.runMassflowSolver()
@@ -572,18 +517,24 @@ class _MainWindow(QMainWindow):
         self.centralWidget.setConnLabelVis(self.labelVisState)
 
     def exportHydraulicsDdck(self):
-        statusQuo = self.labelVisState
-        if not statusQuo:
-            self.toggleConnLabels()
         self.centralWidget.exportHydraulics(exportTo="ddck")
-        if not statusQuo:
-            self.toggleConnLabels()
 
     def exportHydraulicControl(self):
         self.centralWidget.exportHydraulicControl()
 
     def exportDck(self):
-        dckBuilder.buildDck(self.projectFolder)
+        jsonResult = self.centralWidget.exportDdckPlaceHolderValuesJsonFile()
+        if _res.isError(jsonResult):
+            errorMessage = f"The placeholder values JSON file could not be generated: {jsonResult.message}"
+            showErrorMessageBox(errorMessage)
+            return
+
+        builder = buildDck.buildDck(self.projectFolder)
+
+        result = builder.buildTrnsysDeck()
+        if _res.isError(result):
+            errorMessage = f"The deck file could not be generated: {result.message}"
+            showErrorMessageBox(errorMessage)
 
     def toggleEditorMode(self):
         self.logger.info("Toggling editor mode")
@@ -598,158 +549,48 @@ class _MainWindow(QMainWindow):
         self.centralWidget.snapGrid = not self.centralWidget.snapGrid
         self.centralWidget.diagramScene.update()
 
-    def createSelection(self):
-        self.centralWidget.clearSelectionGroup()
-        self.centralWidget.selectionMode = True
-        self.centralWidget.copyMode = False
-        self.centralWidget.groupMode = False
-        self.centralWidget.multipleSelectMode = True
-
-    def deleteMultiple(self):
-        # print("pressed del")
-        temp = []
-        self.logger.info("Child Items")
-        self.logger.info(self.centralWidget.selectionGroupList.childItems())
-
-        for t in self.centralWidget.selectionGroupList.childItems():
-            temp.append(t)
-            self.centralWidget.selectionGroupList.removeFromGroup(t)
-
-        for t in temp:
-            if isinstance(t, BlockItem):
-                t.deleteBlock()
-            elif isinstance(t, Connection):
-                t.deleteConn()
-            elif isinstance(t, GraphicalItem):
-                t.deleteBlock()
-            else:
-                self.logger.info("Neiter a Block nor Connection in copyGroupList ")
-
     def runMassflowSolver(self):
         self.logger.info("Running massflow solver...")
 
         exportPath = self.centralWidget.exportHydraulics(exportTo="mfs")
-        self.exportedTo = exportPath
-        self.logger.info(exportPath)
-        if exportPath != "None":
-            msgb = QMessageBox(self)
-            if not self.centralWidget.trnsysPath.is_file():
-                msgb.setText(
-                    "TRNExe.exe not found! Consider correcting the path in the settings."
-                )
-                msgb.exec()
-                return 0, 0
-            self.logger.info("trnsyspath: %s", self.centralWidget.trnsysPath)
-            # cmd = f"{self.centralWidget.trnsysPath} {exportPath} /H"
-            errorStatement = ""
-            try:
-                subprocess.run(
-                    [str(self.centralWidget.trnsysPath), exportPath, "/H"], check=True
-                )
-                mfrFile = os.path.join(
-                    self.projectFolder, self.projectFolder.split("\\")[-1] + "_Mfr.prt"
-                )
-                tempFile = os.path.join(
-                    self.projectFolder, self.projectFolder.split("\\")[-1] + "_T.prt"
-                )
-                self.calledByVisualizeMf = False
-                return mfrFile, tempFile
-            except ValueError as e:
-                self.logger.error("EXCEPTION WHILE TRYING TO EXECUTE RunParallelTrnsys")
-                for words in e.args:
-                    errorStatement += str(words)
-            except OSError as e:
-                self.logger.error("EXCEPTION WHILE TRYING TO EXECUTE RunParallelTrnsys")
-                errorStatement = str(e)
-            except:
-                self.logger.error(
-                    "UNDEFINED EXCEPTION WHILE TRYING TO EXECUTE RunParallelTrnsys"
-                )
-
-            messageText = (
-                "Exception while trying to execute runMassflowSolver:\n\n"
-                + errorStatement
-            )
-            qmb = QMessageBox()
-            qmb.setText(messageText)
-            qmb.setStandardButtons(QMessageBox.Ok)
-            qmb.setDefaultButton(QMessageBox.Ok)
-            qmb.exec()
-
+        if not exportPath:
             return None
 
-    def loadVisualization(self):
-        MfrFile = QFileDialog.getOpenFileName(
-            self, "Select Mfr File", "exports", filter="*_Mfr.prt"
-        )[0]
-        if MfrFile == "":
-            msgb = QMessageBox(self)
-            msgb.setText("No Mfr file chosen!")
-            msgb.exec()
-            return
-        TempFile = QFileDialog.getOpenFileName(
-            self, "Select Temperature File", "exports", filter="*_T.prt"
-        )[0]
-        if TempFile == "":
-            msgb = QMessageBox(self)
-            msgb.setText("No Temperature file chosen!")
-            msgb.exec()
-            return
+        self.exportedTo = exportPath
+        self.logger.info(exportPath)
 
-        selectedMfrFileName = str(MfrFile).split("/")[-1][:-8]
-        selectedTempFileName = str(TempFile).split("/")[-1][:-6]
+        if not self.centralWidget.trnsysPath.is_file():
+            errorMessage = "TRNExe.exe not found! Consider correcting the path in the settings."
+            showErrorMessageBox(errorMessage)
+            return None
 
-        currentFilePath = self.currentFile
-        if "\\" in currentFilePath:
-            diaName = currentFilePath.split("\\")[-1][:-5]
-        elif "/" in currentFilePath:
-            diaName = currentFilePath.split("/")[-1][:-5]
-        else:
-            diaName = currentFilePath
-
-        if selectedMfrFileName == selectedTempFileName == diaName:
-            MassFlowVisualizer(self, MfrFile, TempFile)
-            self.massFlowEnabled = True
-        else:
-            self.logger.info(selectedMfrFileName, selectedTempFileName, diaName)
-            msgb = QMessageBox(self)
-            msgb.setText(
-                "MFR or Temperature file does not correspond to current diagram!"
+        try:
+            subprocess.run(
+                [str(self.centralWidget.trnsysPath), exportPath, "/H"], check=True
             )
-            msgb.exec()
+            mfrFile = os.path.join(
+                self.projectFolder, self.projectFolder.split("\\")[-1] + "_Mfr.prt"
+            )
+            tempFile = os.path.join(
+                self.projectFolder, self.projectFolder.split("\\")[-1] + "_T.prt"
+            )
+            self.calledByVisualizeMf = False
+            return mfrFile, tempFile
+        except Exception as exception:
+            errorMessage = f"An exception occurred while trying to execute the mass flow solver: {exception}"
+            showErrorMessageBox(errorMessage)
+            self.logger.error(errorMessage)
+
+            return None
 
     def movePorts(self):
         self.centralWidget.moveDirectPorts = True
 
     def mouseMoveEvent(self, e):
         pass
-        # x = e.x()
-        # y = e.y()
-        #
-        # text = "x: {0},  y: {1}".format(x, y)
-        # self.sb.showMessage(text)
-        # #print("event")
 
-    def showAbout(self):
-        msgb = QMessageBox(self)
-        msgb.setText("PyQt based diagram editor coupled to Trnsys functions")
-        msgb.exec()
-
-    def showVersion(self):
-        msgb = QMessageBox(self)
-        msgb.setText(
-            "Currrent version is " + __version__ + " with status " + __status__
-        )
-        msgb.exec()
-
-    def showCredits(self):
-        msgb = QMessageBox(self)
-        msgb.setText(
-            "<p><b>Contributors:</b></p>"
-            "<p>Stefano Marti, Dani Carbonell, Mattia Battaglia, Jeremias Schmidli, and Martin Neugebauer."
-        )
-        # "Icons made by Jeremias Schmidli and with icons by Vaadin from  www.flaticon.com</p>"
-        msgb.exec()
+    def openPytrnsysOnlineDoc(self):
+        os.system("start \"\" https://pytrnsys.readthedocs.io")
 
     def exportPDF(self):
         self.centralWidget.printPDF()
@@ -818,8 +659,8 @@ class _MainWindow(QMainWindow):
                     self.noErrorConns = False
 
                 elif (
-                    objInput == connToInputFromPort
-                    and objOutput == connToOutputFromPort
+                        objInput == connToInputFromPort
+                        and objOutput == connToOutputFromPort
                 ):
                     msgBox = QMessageBox()
                     msgBox.setText(
@@ -830,15 +671,6 @@ class _MainWindow(QMainWindow):
                     self.noErrorConns = False
         return self.noErrorConns
 
-    def runApp(self):
-        runApp = RunMain()
-        if self.centralWidget.projectPath == "":
-            self.logger.info("Temp path:", self.centralWidget.projectFolder)
-            runApp.runAction(self.centralWidget.projectFolder)
-        else:
-            self.logger.info("Project path:", self.centralWidget.projectPath)
-            runApp.runAction(self.centralWidget.projectPath)
-
     def _createDiagramEditor(self, project: _prj.Project) -> _de.Editor:
         if isinstance(project, _prj.LoadProject):
             self.projectFolder = str(project.jsonFilePath.parent)
@@ -887,7 +719,7 @@ def main():
         return
     project = _ccl.value(maybeCancelled)
 
-    form = _MainWindow(logger, project)
+    form = MainWindow(logger, project)
     form.showMaximized()
     form.show()
     form.ensureSettingsExist()
@@ -897,5 +729,14 @@ def main():
     tracer.run(lambda: app.exec())
 
 
+def generateUI():
+    if pkg_resources.get_distribution("pytrnsys-gui").parsed_version.local.endswith('dev'):
+        uiGenerateFilePath = _pl.Path(
+            __file__).parent.parent / "dev-tools" / "generateGuiClassesFromQtCreatorStudioUiFiles.py"
+        cmd = ["python.exe", uiGenerateFilePath]
+        subprocess.run(cmd, check=True)
+
+
 if __name__ == "__main__":
+    generateUI()
     main()
