@@ -7,7 +7,7 @@ from PyQt5.QtCore import Qt
 from PyQt5.QtGui import QPen, QColor
 from PyQt5.QtWidgets import QGraphicsItemGroup, QGraphicsLineItem, QMenu
 
-from trnsysGUI.PortItem import PortItem
+import trnsysGUI.createSinglePipePortItem as _cspi
 
 
 class HeatExchanger(QGraphicsItemGroup):
@@ -16,16 +16,16 @@ class HeatExchanger(QGraphicsItemGroup):
     PORT_ITEM_PROTRUSION_SIZE_IN_PIXELS = 8
 
     def __init__(
-        self,
-        sideNr,
-        width,
-        relativeInputHeight,
-        relativeOutputHeight,
-        storageTankWidth,
-        storageTankHeight,
-        parent,
-        name="Untitled",
-        **kwargs
+            self,
+            trnsysId,
+            sideNr,
+            width,
+            relativeInputHeight,
+            relativeOutputHeight,
+            storageTankWidth,
+            storageTankHeight,
+            parent,
+            name
     ):
         super().__init__(parent)
         self.parent = parent
@@ -36,13 +36,12 @@ class HeatExchanger(QGraphicsItemGroup):
 
         self.sSide = sideNr
         self.id = self.parent.parent.parent().idGen.getID()
-        self.trnsysId = self.parent.parent.parent().idGen.getTrnsysID()
+        self.trnsysId = trnsysId
 
         self.parent.heatExchangers.append(self)
         self.setZValue(100)
-
-        self.port1 = PortItem("i", self.sSide, self.parent)
-        self.port2 = PortItem("o", self.sSide, self.parent)
+        self.port1 = _cspi.createSinglePipePortItem("i", self.sSide, self.parent)
+        self.port2 = _cspi.createSinglePipePortItem("o", self.sSide, self.parent)
 
         self.parent.inputs.append(self.port1)
         self.parent.outputs.append(self.port2)
@@ -54,19 +53,11 @@ class HeatExchanger(QGraphicsItemGroup):
             relativeOutputHeight,
         )
 
-        if kwargs == {} or "tempHx" in kwargs:
-            self.logger.debug("Creating new HeatExchanger")
-            if kwargs == {}:
-                self.displayName = name + str(self.id)
-            elif "tempHx" in kwargs:
-                self.displayName = name
-            self._setPortsColor()
-        else:
-            if "loadedHx" in kwargs:
-                self.logger.debug("Loading existing HeatExchanger")
-                self.displayName = name
+        self.displayName = name
 
-    def _setPortsColor(self):
+        self._draw()
+
+    def _draw(self):
         self.port1.setZValue(100)
         self.port2.setZValue(100)
 
@@ -77,7 +68,7 @@ class HeatExchanger(QGraphicsItemGroup):
         self.port1.visibleColor = randomColor
         self.port2.visibleColor = randomColor
 
-        self._draw()
+        self._drawCoils()
 
     def setId(self, newId):
         self.id = newId
@@ -85,7 +76,7 @@ class HeatExchanger(QGraphicsItemGroup):
     def setParent(self, p):
         self.parent = p
 
-        if p.name is "StorageTank":
+        if p.name == "StorageTank":
             self.logger.debug("p is a StorageTank")
             self.setParentItem(p)
         else:
@@ -99,10 +90,6 @@ class HeatExchanger(QGraphicsItemGroup):
         a1 = menu.addAction("Rename...")
         a1.triggered.connect(self.renameHx)
 
-        a2 = menu.addAction("PLACEHOLDER TO FILL THIS EMPTY SPACE (Delete...)")
-
-        a3 = menu.addAction("PLACEHOLDER TO FILL THIS EMPTY SPACE (Change position)")
-
         menu.exec_(event.screenPos())
 
     def mousePressEvent(self, event):
@@ -110,7 +97,6 @@ class HeatExchanger(QGraphicsItemGroup):
         self.logger.debug("pressed")
 
     def renameHx(self):
-        # dia = hxDlg(self, self.scene().parent())
         self.scene().parent().showHxDlg(self)
 
     def rename(self, newName):
@@ -137,7 +123,7 @@ class HeatExchanger(QGraphicsItemGroup):
             self.relativeOutputHeight,
         )
 
-        self._draw()
+        self._drawCoils()
 
     def setRelativeHeights(self, relativeInputHeight: float, relativeOutputHeight: float) -> None:
         self._clearDrawing()
@@ -149,9 +135,9 @@ class HeatExchanger(QGraphicsItemGroup):
             relativeOutputHeight,
         )
 
-        self._draw()
+        self._drawCoils()
 
-    def _draw(self):
+    def _drawCoils(self):
         sign = 1 if self.sSide == 0 else -1
 
         x, y = self._getPos()
@@ -205,11 +191,11 @@ class HeatExchanger(QGraphicsItemGroup):
         self._lines = []
 
     def _setRelativeHeightsAndTankSize(
-        self,
-        storageTankWidth,
-        storageTankHeight,
-        relativeInputHeight,
-        relativeOutputHeight,
+            self,
+            storageTankWidth,
+            storageTankHeight,
+            relativeInputHeight,
+            relativeOutputHeight,
     ):
         self._storageTankWidth = storageTankWidth
         self._storageTankHeight = storageTankHeight
@@ -217,7 +203,7 @@ class HeatExchanger(QGraphicsItemGroup):
         self.relativeOutputHeight = relativeOutputHeight
         self.relativeInputHeight = relativeInputHeight
 
-        relativeHeight = relativeInputHeight - relativeOutputHeight
+        relativeHeight = abs(relativeInputHeight - relativeOutputHeight)
         absoluteHeight = relativeHeight * storageTankHeight
 
         self.h = absoluteHeight - absoluteHeight % self.COIL_HEIGHT_IN_PIXELS
@@ -228,12 +214,15 @@ class HeatExchanger(QGraphicsItemGroup):
         x, y = self._getPos()
         sign = 1 if self.sSide == 0 else -1
         xWithProtrusion = x - sign * self.PORT_ITEM_PROTRUSION_SIZE_IN_PIXELS
-        self.port1.setPos(xWithProtrusion, y)
-        self.port2.setPos(xWithProtrusion, y + self.h)
+        if self.relativeInputHeight > self.relativeOutputHeight:
+            self.port1.setPos(xWithProtrusion, y)
+            self.port2.setPos(xWithProtrusion, y + self.h)
+        else:
+            self.port1.setPos(xWithProtrusion, y + self.h)
+            self.port2.setPos(xWithProtrusion, y)
 
     def _getPos(self):
         x = 0 if self.sSide == 0 else self._storageTankWidth
-        y = self._storageTankHeight - self.relativeInputHeight * self._storageTankHeight
+        topPortRelativeHeight = max(self.relativeInputHeight, self.relativeOutputHeight)
+        y = self._storageTankHeight - topPortRelativeHeight * self._storageTankHeight
         return x, y
-
-
