@@ -5,28 +5,29 @@ import os
 import shutil
 import typing as _tp
 
-from PyQt5.QtCore import QSize
-from PyQt5.QtGui import QPixmap
 from PyQt5.QtWidgets import QTreeView
 
+import trnsysGUI.createSinglePipePortItem as _cspi
+import trnsysGUI.images as _img
+import trnsysGUI.massFlowSolver.networkModel as _mfn
 from trnsysGUI.BlockItem import BlockItem
 from trnsysGUI.MyQFileSystemModel import MyQFileSystemModel
 from trnsysGUI.MyQTreeView import MyQTreeView
-from trnsysGUI.PortItem import PortItem
-import trnsysGUI.images as _img
+from trnsysGUI.massFlowSolver import InternalPiping, MassFlowNetworkContributorMixin
 
 
-class HeatPumpTwoHx(BlockItem):
+class HeatPumpTwoHx(BlockItem, MassFlowNetworkContributorMixin):
     def __init__(self, trnsysType, parent, **kwargs):
         super(HeatPumpTwoHx, self).__init__(trnsysType, parent, **kwargs)
 
-        self.inputs.append(PortItem("i", 0, self))
-        self.inputs.append(PortItem("i", 2, self))
-        self.inputs.append(PortItem("i", 2, self))
+        self.inputs.append(_cspi.createSinglePipePortItem("i", 0, self))
+        self.inputs.append(_cspi.createSinglePipePortItem("i", 2, self))
+        self.inputs.append(_cspi.createSinglePipePortItem("i", 2, self))
+
+        self.outputs.append(_cspi.createSinglePipePortItem("o", 0, self))
+        self.outputs.append(_cspi.createSinglePipePortItem("o", 2, self))
+        self.outputs.append(_cspi.createSinglePipePortItem("o", 2, self))
 
-        self.outputs.append(PortItem("o", 0, self))
-        self.outputs.append(PortItem("o", 2, self))
-        self.outputs.append(PortItem("o", 2, self))
         self.loadedFiles = []
 
         # For restoring correct order of trnsysObj list
@@ -59,14 +60,15 @@ class HeatPumpTwoHx(BlockItem):
         lx = (w - lw) / 2
         self.label.setPos(lx, h)
 
-        self.origInputsPos = [[0, delta], [w, delta], [w, h - 2 * delta]]
-        self.origOutputsPos = [[0, h - delta], [w, 2 * delta], [w, h - delta]]
-        self.inputs[0].setPos(self.origInputsPos[0][0], self.origInputsPos[0][1])
-        self.inputs[1].setPos(self.origInputsPos[1][0], self.origInputsPos[1][1])
-        self.inputs[2].setPos(self.origInputsPos[2][0], self.origInputsPos[2][1])
-        self.outputs[0].setPos(self.origOutputsPos[0][0], self.origOutputsPos[0][1])
-        self.outputs[1].setPos(self.origOutputsPos[1][0], self.origOutputsPos[1][1])
-        self.outputs[2].setPos(self.origOutputsPos[2][0], self.origOutputsPos[2][1])
+        self.origInputsPos = [[0, delta], [w, h - delta], [w, 2 * delta]]  # inlet of [evap, cond, cond]
+        self.origOutputsPos = [[0, h - delta], [w, h - 2 * delta], [w, delta]]  # outlet of [evap, cond, cond]
+
+        self.inputs[0].setPos(self.origInputsPos[0][0], self.origInputsPos[0][1])  # evaporator
+        self.inputs[1].setPos(self.origInputsPos[1][0], self.origInputsPos[1][1])  # bottom condenser
+        self.inputs[2].setPos(self.origInputsPos[2][0], self.origInputsPos[2][1])  # top condenser
+        self.outputs[0].setPos(self.origOutputsPos[0][0], self.origOutputsPos[0][1])  # evaporator
+        self.outputs[1].setPos(self.origOutputsPos[1][0], self.origOutputsPos[1][1])  # bottom condenser
+        self.outputs[2].setPos(self.origOutputsPos[2][0], self.origOutputsPos[2][1])  # top condenser
 
         self.updateFlipStateH(self.flippedH)
         self.updateFlipStateV(self.flippedV)
@@ -103,9 +105,8 @@ class HeatPumpTwoHx(BlockItem):
             dct["trnsysID"] = self.trnsysId
             dct["childIds"] = self.childIds
             dct["FlippedH"] = self.flippedH
-            dct["FlippedV"] = self.flippedH
+            dct["FlippedV"] = self.flippedV
             dct["RotationN"] = self.rotationN
-            dct["GroupName"] = self.groupName
 
             dictName = "Block-"
 
@@ -130,9 +131,6 @@ class HeatPumpTwoHx(BlockItem):
         self.trnsysId = i["trnsysID"]
         self.id = i["ID"]
 
-        self.groupName = "defaultGroup"
-        self.setBlockToGroup(i["GroupName"])
-
         resBlockList.append(self)
 
     def decodePaste(self, i, offset_x, offset_y, resConnList, resBlockList, **kwargs):
@@ -150,11 +148,7 @@ class HeatPumpTwoHx(BlockItem):
             self.logger.debug("Output at heatExchanger")
 
         self.setPos(float(i["HeatPumpPosition"][0] + offset_x), float(i["HeatPumpPosition"][1] + offset_y))
-        # self.trnsysId = i["trnsysID"]
-        # self.id = i["ID"]
 
-        self.groupName = "defaultGroup"
-        self.setBlockToGroup(i["GroupName"])
         resBlockList.append(self)
 
     def exportBlackBox(self):
@@ -164,98 +158,38 @@ class HeatPumpTwoHx(BlockItem):
         status = "success"
         return status, equations
 
-    def exportParametersFlowSolver(self, descConnLength):
-        f = ""
-        for i in range(len(self.inputs)):
-            for c in self.inputs[i].connectionList:
-                if len(self.outputs[i].connectionList) > 0:
-                    # HeatPumpTwoHx exportConnsString has 3 lines
-                    if i == 0:
-                        temp = (
-                            str(c.trnsysId) + " " + str(self.outputs[i].connectionList[0].trnsysId) + " 0 0 "
-                        )  # + str(t.childIds[0])
-                        temp += " " * (descConnLength - len(temp))
+    def getInternalPiping(self) -> InternalPiping:
+        evaporatorInput = _mfn.PortItem("evaporatorInput", _mfn.PortItemType.INPUT)
+        evaporatorOutput = _mfn.PortItem("evaporatorOutput", _mfn.PortItemType.OUTPUT)
+        evaporatorPipe = _mfn.Pipe(f"{self.displayName}Evap", self.childIds[0], evaporatorInput, evaporatorOutput)
 
-                        self.exportConnsString += temp + "\n"
-                        f += temp + "!" + str(self.childIds[0]) + " : " + self.displayName + "Side1" + "\n"
+        condenser1Input = _mfn.PortItem("condenser1Input", _mfn.PortItemType.INPUT)
+        condenser1Output = _mfn.PortItem("condenser1Output", _mfn.PortItemType.OUTPUT)
+        condenser1Pipe = _mfn.Pipe(f"{self.displayName}Cond1", self.childIds[1], condenser1Input, condenser1Output)
 
-                    elif i == 1:
-                        temp = (
-                            str(c.trnsysId) + " " + str(self.outputs[i].connectionList[0].trnsysId) + " 0 0 "
-                        )  # + str(t.childIds[1])
-                        temp += " " * (descConnLength - len(temp))
+        condenser2Input = _mfn.PortItem("condenser2Input", _mfn.PortItemType.INPUT)
+        condenser2Output = _mfn.PortItem("condenser2Output", _mfn.PortItemType.OUTPUT)
+        condenser2Pipe = _mfn.Pipe(f"{self.displayName}Cond2", self.childIds[2], condenser2Input, condenser2Output)
 
-                        self.exportConnsString += temp + "\n"
-                        f += temp + "!" + str(self.childIds[1]) + " : " + self.displayName + "Side2" + "\n"
+        modelPortItemsToGraphicalPortItem = {
+            evaporatorInput: self.inputs[0],
+            evaporatorOutput: self.outputs[0],
+            condenser1Input: self.inputs[1],
+            condenser1Output: self.outputs[1],
+            condenser2Input: self.inputs[2],
+            condenser2Output: self.outputs[2]
+        }
+        nodes = [evaporatorPipe, condenser1Pipe, condenser2Pipe]
 
-                    elif i == 2:
-                        temp = (
-                            str(c.trnsysId) + " " + str(self.outputs[i].connectionList[0].trnsysId) + " 0 0 "
-                        )  # + str(t.childIds[1])
-                        temp += " " * (descConnLength - len(temp))
-
-                        self.exportConnsString += temp + "\n"
-                        f += temp + "!" + str(self.childIds[2]) + " : " + self.displayName + "Side3" + "\n"
-                    else:
-                        f += "Error: There are more inputs than trnsysIds" + "\n"
-
-                    # Presumably used only for storing the order of connections
-                    self.trnsysConn.append(c)
-                    self.trnsysConn.append(self.outputs[i].connectionList[0])
-
-                else:
-                    f += "Output of ExternalHx for input[{0}] is not connected ".format(i) + "\n"
-
-        return f
-
-    def exportInputsFlowSolver1(self):
-        return "0,0 0,0 0,0", 3
-
-    def exportInputsFlowSolver2(self):
-        f = ""
-        f += (
-            " "
-            + str(self.exportInitialInput)
-            + " "
-            + str(self.exportInitialInput)
-            + " "
-            + str(self.exportInitialInput)
-            + " "
-        )
-        return f, 3
-
-    def exportOutputsFlowSolver(self, prefix, abc, equationNumber, simulationUnit):
-        tot = ""
-        for j in range(3):
-            for i in range(0, 3):
-                if i < 2:
-                    temp = (
-                        prefix
-                        + self.displayName
-                        + "-Side"
-                        + str(j)
-                        + "_"
-                        + abc[i]
-                        + "=["
-                        + str(simulationUnit)
-                        + ","
-                        + str(equationNumber)
-                        + "]\n"
-                    )
-                    tot += temp
-                    self.exportEquations.append(temp)
-                    # nEqUsed += 1  # DC
-                equationNumber += 1  # DC-ERROR it should count anyway
-
-        return tot, equationNumber, 6
+        return InternalPiping(nodes, modelPortItemsToGraphicalPortItem)
 
     def getSubBlockOffset(self, c):
         for i in range(3):
             if (
-                self.inputs[i] == c.toPort
-                or self.inputs[i] == c.fromPort
-                or self.outputs[i] == c.toPort
-                or self.outputs[i] == c.fromPort
+                    self.inputs[i] == c.toPort
+                    or self.inputs[i] == c.fromPort
+                    or self.outputs[i] == c.toPort
+                    or self.outputs[i] == c.fromPort
             ):
                 return i
 
@@ -267,12 +201,7 @@ class HeatPumpTwoHx(BlockItem):
         self.logger.debug(self.parent.parent())
         pathName = self.displayName
         if self.parent.parent().projectPath == "":
-            # self.path = os.path.dirname(__file__)
-            # self.path = os.path.join(self.path, 'default')
             self.path = self.parent.parent().projectFolder
-            # now = datetime.now()
-            # self.fileName = now.strftime("%Y%m%d%H%M%S")
-            # self.path = os.path.join(self.path, self.fileName)
         else:
             self.path = self.parent.parent().projectPath
         self.path = os.path.join(self.path, "ddck")
@@ -293,28 +222,8 @@ class HeatPumpTwoHx(BlockItem):
         self.tree.setSortingEnabled(True)
         self.parent.parent().splitter.addWidget(self.tree)
 
-    # def loadFile(self, file):
-    #     filePath = self.parent.parent().projectPath
-    #     msgB = QMessageBox()
-    #     if filePath == '':
-    #         msgB.setText("Please select a project path before loading!")
-    #         msgB.exec_()
-    #     else:
-    #         self.logger.debug("file loaded into %s" % filePath)
-    #         shutil.copy(file, filePath)
-
-    def updateTreePath(self, path):
-        """
-        When the user chooses the project path for the file explorers, this method is called
-        to update the root path.
-        """
-        pathName = self.displayName
-        self.path = os.path.join(path, "ddck")
-        self.path = os.path.join(self.path, pathName)
-        if not os.path.exists(self.path):
-            os.makedirs(self.path)
-        self.model.setRootPath(self.path)
-        self.tree.setRootIndex(self.model.index(self.path))
+    def hasDdckPlaceHolders(self):
+        return True
 
     def deleteBlock(self):
         """
@@ -322,10 +231,8 @@ class HeatPumpTwoHx(BlockItem):
         """
         self.logger.debug("Block " + str(self) + " is deleting itself (" + self.displayName + ")")
         self.deleteConns()
-        # self.logger.debug("self.parent.parent" + str(self.parent.parent()))
         self.parent.parent().trnsysObj.remove(self)
         self.logger.debug("deleting block " + str(self) + self.displayName)
-        # self.logger.debug("self.scene is" + str(self.parent.scene()))
         self.parent.scene().removeItem(self)
         widgetToRemove = self.parent.parent().findChild(QTreeView, self.displayName + "Tree")
         shutil.rmtree(self.path)
@@ -338,7 +245,7 @@ class HeatPumpTwoHx(BlockItem):
             self.logger.debug("Deleted widget")
         del self
 
-    def setName(self, newName):
+    def setDisplayName(self, newName):
         """
         Overridden method to also change folder name
         """
@@ -347,7 +254,6 @@ class HeatPumpTwoHx(BlockItem):
         self.model.setName(self.displayName)
         self.tree.setObjectName("%sTree" % self.displayName)
         self.logger.debug(os.path.dirname(self.path))
-        # destPath = str(os.path.dirname(self.path))+'\\HPTwoHx_'+self.displayName
         destPath = os.path.join(os.path.split(self.path)[0], self.displayName)
         if os.path.exists(self.path):
             os.rename(self.path, destPath)
