@@ -6,15 +6,14 @@ import os
 import shutil
 import typing as _tp
 
-
-from PyQt5.QtCore import QSize
-from PyQt5.QtGui import QPixmap
 from PyQt5.QtWidgets import QTreeView
 
+import trnsysGUI.images as _img
+import trnsysGUI.massFlowSolver.networkModel as _mfn
 from trnsysGUI.BlockItemFourPorts import BlockItemFourPorts
 from trnsysGUI.MyQFileSystemModel import MyQFileSystemModel
 from trnsysGUI.MyQTreeView import MyQTreeView
-import trnsysGUI.images as _img
+from trnsysGUI.massFlowSolver import InternalPiping
 
 
 class IceStorageTwoHx(BlockItemFourPorts):
@@ -68,12 +67,7 @@ class IceStorageTwoHx(BlockItemFourPorts):
         self.logger.debug(self.parent.parent())
         pathName = self.displayName
         if self.parent.parent().projectPath == "":
-            # self.path = os.path.dirname(__file__)
-            # self.path = os.path.join(self.path, 'default')
             self.path = self.parent.parent().projectFolder
-            # now = datetime.now()
-            # self.fileName = now.strftime("%Y%m%d%H%M%S")
-            # self.path = os.path.join(self.path, self.fileName)
         else:
             self.path = self.parent.parent().projectPath
         self.path = os.path.join(self.path, "ddck")
@@ -94,18 +88,8 @@ class IceStorageTwoHx(BlockItemFourPorts):
         self.tree.setSortingEnabled(True)
         self.parent.parent().splitter.addWidget(self.tree)
 
-    def updateTreePath(self, path):
-        """
-        When the user chooses the project path for the file explorers, this method is called
-        to update the root path.
-        """
-        pathName = self.displayName
-        self.path = os.path.join(path, "ddck")
-        self.path = os.path.join(self.path, pathName)
-        if not os.path.exists(self.path):
-            os.makedirs(self.path)
-        self.model.setRootPath(self.path)
-        self.tree.setRootIndex(self.model.index(self.path))
+    def hasDdckPlaceHolders(self):
+        return True
 
     def deleteBlock(self):
         """
@@ -113,10 +97,8 @@ class IceStorageTwoHx(BlockItemFourPorts):
         """
         self.logger.debug("Block " + str(self) + " is deleting itself (" + self.displayName + ")")
         self.deleteConns()
-        # self.logger.debug("self.parent.parent" + str(self.parent.parent()))
         self.parent.parent().trnsysObj.remove(self)
         self.logger.debug("deleting block " + str(self) + self.displayName)
-        # self.logger.debug("self.scene is" + str(self.parent.scene()))
         self.parent.scene().removeItem(self)
         widgetToRemove = self.parent.parent().findChild(QTreeView, self.displayName + "Tree")
         shutil.rmtree(self.path)
@@ -129,7 +111,7 @@ class IceStorageTwoHx(BlockItemFourPorts):
             self.logger.debug("Deleted widget")
         del self
 
-    def setName(self, newName):
+    def setDisplayName(self, newName):
         """
         Overridden method to also change folder name
         """
@@ -138,60 +120,26 @@ class IceStorageTwoHx(BlockItemFourPorts):
         self.model.setName(self.displayName)
         self.tree.setObjectName("%sTree" % self.displayName)
         self.logger.debug(os.path.dirname(self.path))
-        # destPath = str(os.path.dirname(self.path))+'\\IceStorage_'+self.displayName
         destPath = os.path.join(os.path.split(self.path)[0], self.displayName)
         if os.path.exists(self.path):
             os.rename(self.path, destPath)
             self.path = destPath
             self.logger.debug(self.path)
 
-    def updateTreePath(self, path):
-        """
-        When the user chooses the project path for the file explorers, this method is called
-        to update the root path.
-        """
-        pathName = self.displayName
-        self.path = os.path.join(path, "ddck")
-        self.path = os.path.join(self.path, pathName)
-        if not os.path.exists(self.path):
-            os.makedirs(self.path)
-        self.model.setRootPath(self.path)
-        self.tree.setRootIndex(self.model.index(self.path))
+    def getInternalPiping(self) -> InternalPiping:
+        side1Input = _mfn.PortItem("leftSideInput", _mfn.PortItemType.INPUT)
+        side1Output = _mfn.PortItem("leftSideOutput", _mfn.PortItemType.OUTPUT)
+        side1Pipe = _mfn.Pipe(f"{self.displayName}leftSide", self.childIds[0], side1Input, side1Output)
 
-    def deleteBlock(self):
-        """
-        Overridden method to also delete folder
-        """
-        self.logger.debug("Block " + str(self) + " is deleting itself (" + self.displayName + ")")
-        self.deleteConns()
-        # self.logger.debug("self.parent.parent" + str(self.parent.parent()))
-        self.parent.parent().trnsysObj.remove(self)
-        self.logger.debug("deleting block " + str(self) + self.displayName)
-        # self.logger.debug("self.scene is" + str(self.parent.scene()))
-        self.parent.scene().removeItem(self)
-        widgetToRemove = self.parent.parent().findChild(QTreeView, self.displayName + "Tree")
-        shutil.rmtree(self.path)
-        self.deleteLoadedFile()
-        try:
-            widgetToRemove.hide()
-        except AttributeError:
-            self.logger.debug("Widget doesnt exist!")
-        else:
-            self.logger.debug("Deleted widget")
-        del self
+        side2Input = _mfn.PortItem("rightSideInput", _mfn.PortItemType.INPUT)
+        side2Output = _mfn.PortItem("rightSideOutput", _mfn.PortItemType.OUTPUT)
+        side2Pipe = _mfn.Pipe(f"{self.displayName}rightSide", self.childIds[1], side2Input, side2Output)
 
-    def setName(self, newName):
-        """
-        Overridden method to also change folder name
-        """
-        self.displayName = newName
-        self.label.setPlainText(newName)
-        self.model.setName(self.displayName)
-        self.tree.setObjectName("%sTree" % self.displayName)
-        self.logger.debug(os.path.dirname(self.path))
-        # destPath = str(os.path.dirname(self.path))+'\\IceStorage_'+self.displayName
-        destPath = os.path.join(os.path.split(self.path)[0], self.displayName)
-        if os.path.exists(self.path):
-            os.rename(self.path, destPath)
-            self.path = destPath
-            self.logger.debug(self.path)
+        modelPortItemsToGraphicalPortItem = {
+            side1Input: self.inputs[0],
+            side1Output: self.outputs[0],
+            side2Input: self.inputs[1],
+            side2Output: self.outputs[1]
+        }
+
+        return InternalPiping([side1Pipe, side2Pipe], modelPortItemsToGraphicalPortItem)
