@@ -1,16 +1,17 @@
 import dataclasses as _dc
 
-import trnsysGUI.PortItem as _port
+import trnsysGUI.singlePipePortItem as _port
+import trnsysGUI.storageTank.side as _sd
 
 
 @_dc.dataclass
 class DirectPortPair:
     trnsysId: int
-    fromPort: _port.PortItem  # type: ignore[name-defined]
-    toPort: _port.PortItem  # type: ignore[name-defined]
+    fromPort: _port.SinglePipePortItem  # type: ignore[name-defined]
+    toPort: _port.SinglePipePortItem  # type: ignore[name-defined]
     relativeInputHeight: float
     relativeOutputHeight: float
-    isOnLeftSide: bool
+    side: _sd.Side
 
     @property
     def relativeInputHeightPercent(self):
@@ -20,10 +21,6 @@ class DirectPortPair:
     def relativeOutputHeightPercent(self):
         return self._toPercent(self.relativeOutputHeight)
 
-    @property
-    def side(self) -> str:
-        return "Left" if self.isOnLeftSide else "Right"
-
     def setRelativeHeights(self,
                            relativeInputHeight: float,
                            relativeOutputHeight: float,
