@@ -2,6 +2,8 @@
 # type: ignore
 
 import os
+import pathlib as _pl
+
 import numpy as num
 
 
@@ -38,11 +40,11 @@ class Type1924_TesPlugFlow:
 
         line = "EQUATIONS 3\n"
         lines = lines + line
-        line = "Thx%dIn_Tes%d = %s ! @connectDdck\n" % (idHx, nTes, connectorHx[idHx - 1]["T"])
+        line = "Thx%dIn_Tes%d = %s\n" % (idHx, nTes, connectorHx[idHx - 1]["T"])
         lines = lines + line
-        line = "Mfrhx%d_Tes%d = %s ! @connectDdck\n" % (idHx, nTes, connectorHx[idHx - 1]["Mfr"])
+        line = "Mfrhx%d_Tes%d = %s\n" % (idHx, nTes, connectorHx[idHx - 1]["Mfr"])
         lines = lines + line
-        line = "Thx%dInRev_Tes%d = %s ! @connectDdck\n" % (idHx, nTes, connectorHx[idHx - 1]["Trev"])
+        line = "Thx%dInRev_Tes%d = %s\n" % (idHx, nTes, connectorHx[idHx - 1]["Trev"])
         lines = lines + line
 
         return lines
@@ -54,11 +56,11 @@ class Type1924_TesPlugFlow:
 
         line = "EQUATIONS 3\n"
         lines = lines + line
-        line = "Tdp%dIn_Tes%d = %s ! @connectDdck\n" % (idPort, nTes, connectorPort[idPort - 1]["T"])
+        line = "Tdp%dIn_Tes%d = %s\n" % (idPort, nTes, connectorPort[idPort - 1]["T"])
         lines = lines + line
-        line = "Mfrdp%d_Tes%d = %s ! @connectDdck\n" % (idPort, nTes, connectorPort[idPort - 1]["Mfr"])
+        line = "Mfrdp%d_Tes%d = %s\n" % (idPort, nTes, connectorPort[idPort - 1]["Mfr"])
         lines = lines + line
-        line = "Tdp%dInRev_Tes%d = %s ! @connectDdck\n" % (idPort, nTes, connectorPort[idPort - 1]["Trev"])
+        line = "Tdp%dInRev_Tes%d = %s\n" % (idPort, nTes, connectorPort[idPort - 1]["Trev"])
         lines = lines + line
 
         return lines
@@ -70,9 +72,9 @@ class Type1924_TesPlugFlow:
         line = "CONSTANTS 2\n"
         lines = lines + line
 
-        line = "zInDp%d_Tes%d=%.2f ! @connectDdck \n" % (idPort + 1, nTes, connectorPort[idPort]["zIn"])
+        line = "zInDp%d_Tes%d=%.2f\n" % (idPort + 1, nTes, connectorPort[idPort]["zIn"])
         lines = lines + line
-        line = "zOutDp%d_Tes%d=%.2f ! @connectDdck \n" % (idPort + 1, nTes, connectorPort[idPort]["zOut"])
+        line = "zOutDp%d_Tes%d=%.2f\n" % (idPort + 1, nTes, connectorPort[idPort]["zOut"])
         lines = lines + line
 
         return lines
@@ -110,18 +112,19 @@ class Type1924_TesPlugFlow:
         line = "CONSTANTS 4\n"
         lines = lines + line
 
-        line = "zInhx%d_Tes%d=%.2f  ! @connectDdck\n" % (idHx, nTes, connectHx[idHx - 1]["zIn"])
+        line = "zInhx%d_Tes%d=%.2f\n" % (idHx, nTes, connectHx[idHx - 1]["zIn"])
         lines = lines + line
-        line = "zOuthx%d_Tes%d=%.2f ! @connectDdck\n" % (idHx, nTes, connectHx[idHx - 1]["zOut"])
+        line = "zOuthx%d_Tes%d=%.2f\n" % (idHx, nTes, connectHx[idHx - 1]["zOut"])
         lines = lines + line
-        line = "Cphx%d_Tes%d=%s     ! @connectDdck\n" % (idHx, nTes, connectHx[idHx - 1]["cp"])
+        line = "Cphx%d_Tes%d=%s\n" % (idHx, nTes, connectHx[idHx - 1]["cp"])
         lines = lines + line
-        line = "Rhohx%d_Tes%d=%s    ! @connectDdck\n" % (idHx, nTes, connectHx[idHx - 1]["rho"])
+        line = "Rhohx%d_Tes%d=%s\n" % (idHx, nTes, connectHx[idHx - 1]["rho"])
         lines = lines + line
 
         return lines
 
-    def getOneHxParValues(self, nTes, idHx):
+    @staticmethod
+    def getOneHxParValues(nTes, idHx):
 
         lines = "*********Constant values of HX=%d***********\n" % idHx
 
@@ -257,15 +260,15 @@ class Type1924_TesPlugFlow:
         line = "ALat_Tes%d = Heigh_Tes%d*PI*Diameter_Tes%d ! m2\n" % (nTes, nTes, nTes)
         lines = lines + line
 
-        line = "UaBot_Tes%d= Ubot_Tes%d*ATop_Tes%d ! @userDefined W/k \n" % (nTes, nTes, nTes)
+        line = "UaBot_Tes%d= Ubot_Tes%d*ATop_Tes%d !  W/k \n" % (nTes, nTes, nTes)
         lines = lines + line
-        line = "Uaz1_Tes%d = Ufoam_Tes%d*ALat_Tes%d/3 ! @userDefined W/k\n" % (nTes, nTes, nTes)
+        line = "Uaz1_Tes%d = Ufoam_Tes%d*ALat_Tes%d/3 !  W/k\n" % (nTes, nTes, nTes)
         lines = lines + line
-        line = "Uaz2_Tes%d = Ufoam_Tes%d*ALat_Tes%d/3 ! @userDefined W/k\n" % (nTes, nTes, nTes)
+        line = "Uaz2_Tes%d = Ufoam_Tes%d*ALat_Tes%d/3 !  W/k\n" % (nTes, nTes, nTes)
         lines = lines + line
-        line = "Uaz3_Tes%d = Ufoam_Tes%d*ALat_Tes%d/3 ! @userDefined W/k\n" % (nTes, nTes, nTes)
+        line = "Uaz3_Tes%d = Ufoam_Tes%d*ALat_Tes%d/3 !  W/k\n" % (nTes, nTes, nTes)
         lines = lines + line
-        line = "UaTop_Tes%d = Ufoam_Tes%d*ATop_Tes%d ! @userDefined W/k\n" % (nTes, nTes, nTes)
+        line = "UaTop_Tes%d = Ufoam_Tes%d*ATop_Tes%d !  W/k\n" % (nTes, nTes, nTes)
         lines = lines + line
 
         return lines
@@ -378,9 +381,9 @@ class Type1924_TesPlugFlow:
             lines = lines + line
 
             for i in range(nHeatSources):
-                line = "zAux%d_Tes%d=%.2f !connectDDck\n" % (i + 1, nTes, connectorAux[i]["zAux"])
+                line = "zAux%d_Tes%d=%.2f\n" % (i + 1, nTes, connectorAux[i]["zAux"])
                 lines = lines + line
-                line = "qAux%d_Tes%d=%.2f !connectDDck\n" % (i + 1, nTes, connectorAux[i]["qAux"])
+                line = "qAux%d_Tes%d=%.2f\n" % (i + 1, nTes, connectorAux[i]["qAux"])
                 lines = lines + line
 
             line = "\n"
@@ -626,19 +629,16 @@ class Type1924_TesPlugFlow:
         line = "EQUATIONS 5\n"
         lines = lines + line
 
-        line = "sumQv_Tes%d     = [%d,176] ! Heat input of all heat exchangers [kW]\n" % (nTes, nUnit)
-        lines = lines + line
-        line = "sumQLoss_Tes%d  = [%d,177] ! Heat Losses of the Tes [kW]\n" % (nTes, nUnit)
-        lines = lines + line
-        line = "sumQAcum_Tes%d  = [%d,178] ! Sensible accumulated heat [kW]\n" % (nTes, nUnit)
-        lines = lines + line
-        line = "sumQPorts_Tes%d = [%d,179] ! Heat Input by direct ports [kW]\n" % (nTes, nUnit)
-        lines = lines + line
-        line = "Imb_Tes%d       = [%d,64]  ! Heat Imbalance in Tes  IMB = sumQv - sumQLoss -sumQAcum + sumQPort\n" % (
-            nTes,
-            nUnit,
-        )
-        lines = lines + line
+        line = "Qv_Tes%d     = [%d,176] ! Heat input of all heat exchangers and auxiliary heat sources [kW]\n"%(nTes,nUnit)
+        lines=lines+line
+        line = "QLoss_Tes%d  = [%d,177] ! Heat Losses of the Tes [kW]\n"%(nTes,nUnit)
+        lines=lines+line
+        line = "QAcum_Tes%d  = [%d,178] ! Sensible accumulated heat [kW]\n"%(nTes,nUnit)
+        lines=lines+line
+        line = "QPorts_Tes%d = [%d,179] ! Heat Input by direct ports [kW]\n"%(nTes,nUnit)
+        lines=lines+line
+        line = "QImb_Tes%d   = [%d,64]  ! Heat Imbalance in Tes  IMB = sumQv - sumQLoss -sumQAcum + sumQPort\n"%(nTes,nUnit)
+        lines=lines+line
 
         return lines
 
@@ -650,7 +650,7 @@ class Type1924_TesPlugFlow:
         lines = lines + line
         line = "unitPrinter_Tes%d = %d \n" % (nTes, nPrinterUnit)
         lines = lines + line
-        line = "ASSIGN temp\TES%d_MO.Prt unitPrinter_Tes%d\n" % (nTes, nTes)
+        line = "ASSIGN temp\\TES%d_MO.Prt unitPrinter_Tes%d\n" % (nTes, nTes)
         lines = lines + line
         line = "UNIT %d TYPE 46\n" % nPrinterUnit
         lines = lines + line
@@ -671,7 +671,7 @@ class Type1924_TesPlugFlow:
 
         line = "INPUTS %d\n" % nInputs
         lines = lines + line
-        line = "sumQv_Tes1 sumQLoss_Tes1 sumQAcum_Tes1 sumQPorts_Tes1 Imb_Tes1 "
+        line = "Qv_Tes%d QLoss_Tes%d QAcum_Tes%d QPorts_Tes%d QImb_Tes%d "%(nTes,nTes,nTes,nTes,nTes)
         lines = lines + line
         for i in range(inputs["nPorts"]):
             line = "Qdp%d_Tes%d " % (i + 1, nTes)
@@ -766,7 +766,7 @@ class Type1924_TesPlugFlow:
         lines = lines + line
         line = "MassFlows  \n"
         lines = lines + line
-        line = "Tes%d \n"
+        line = "Tes%d\n" % (nTes)
         lines = lines + line
 
         lines = lines + "\n"
@@ -808,7 +808,7 @@ class Type1924_TesPlugFlow:
 
     def getHead(self):
 
-        header = open("C:\Daten\OngoingProject\SolTherm2050\Simulations\ddck\Generic\Head.ddck", "r")
+        header = open(r"C:\Daten\OngoingProject\SolTherm2050\Simulations\ddck\Generic\Head.ddck", "r")
         lines = header.read()
         header.close()
 
@@ -826,7 +826,7 @@ class Type1924_TesPlugFlow:
             lines = lines + self.sLine + "\n"
             lines = lines + self.sLine
             lines = lines + "** To be checked: \n"
-            lines = lines + "** check cp and rho values for the cirquits \n"
+            lines = lines + "** check cp and rho values for the circuits \n"
             lines = lines + "** default is cpwat and rhowat, for solarcirc usually cpbri and rhobri have to be used \n"
             lines = lines + self.sLine + "\n"
             lines = lines + self.sLine
@@ -836,8 +836,9 @@ class Type1924_TesPlugFlow:
             )
             lines = lines + self.sLine
             lines = lines + "EQUATIONS 3\n"
-            lines = lines + ("qSysOut_Tes%sLoss = sumQLoss_Tes%d\n" % (tankName, self.inputs["nTes"]))
-            lines = lines + ("qSysOut_Tes%sAcum = sumQAcum_Tes%d\n" % (tankName, self.inputs["nTes"]))
+            lines = lines + ("qSysOut_Tes%sLoss = QLoss_Tes%d\n" % (tankName, self.inputs["nTes"]))
+            lines = lines + ("qSysOut_Tes%sAcum = QAcum_Tes%d\n" % (tankName, self.inputs["nTes"]))
+
             lines = lines + ("elSysIn_Q_Tes%sAux = qHeatSource_Tes%d\n" % (tankName, self.inputs["nTes"]))
 
         elif typeFile == "dck":
@@ -854,30 +855,13 @@ class Type1924_TesPlugFlow:
         nAux = self.inputs["nHeatSources"]
         nUnit = self.inputs["nUnit"]
 
-        ddcxLines = ""
+        for idPort in range(nPorts):
+            line = self._getOnePortInputs(nTes, idPort + 1, self.connectorsPort)
+            lines = lines + line
 
-        for idPort in range(self.nMaxPorts):
-            if idPort <= nPorts - 1:
-                line = self._getOnePortInputs(nTes, idPort + 1, self.connectorsPort)
-                lines = lines + line
-                inputTemperature = line.split("\n")[1].split("=")[0].replace(" ", "")
-                ddcxLine = (
-                        "T"
-                        + tankName
-                        + "Port"
-                        + self.connectorsPort[idPort]["side"]
-                        + str(int(round(self.connectorsPort[idPort]["zIn"] * 100, 0)))
-                        + "="
-                        + inputTemperature
-                        + "\n"
-                )
-
-                ddcxLines = ddcxLines + ddcxLine
-
-        for idHx in range(self.nMaxHx):
-            if idHx <= nHxs - 1:
-                line = self.getOneHxInputs(nTes, idHx + 1, self.connectorsHx)
-                lines = lines + line
+        for idHx in range(nHxs):
+            line = self.getOneHxInputs(nTes, idHx + 1, self.connectorsHx)
+            lines = lines + line
 
         line = self.getHeatSourcesValues(nTes, nAux, self.connectorsAux)
         lines = lines + line
@@ -891,11 +875,26 @@ class Type1924_TesPlugFlow:
             line = "*** direct port outputs\n"
             lines = lines + line
 
+        ddcxLines = ""
+
         counter = 1
         for idPort in range(nPorts):
             outputTemperature = "Tdp%dOut_Tes%d" % (idPort + 1, nTes)
             line = outputTemperature + "=[%d,%d] ! \n" % (nUnit, counter)
             lines = lines + line
+
+            ddcxLine = (
+                    "T"
+                    + tankName
+                    + "Port"
+                    + self.connectorsPort[idPort]["side"]
+                    + str(int(round(self.connectorsPort[idPort]["zIn"] * 100, 0)))
+                    + "="
+                    + outputTemperature
+                    + "\n"
+            )
+            ddcxLines = ddcxLines + ddcxLine
+
             ddcxLine = (
                     "T"
                     + tankName
@@ -907,6 +906,7 @@ class Type1924_TesPlugFlow:
                     + "\n"
             )
             ddcxLines = ddcxLines + ddcxLine
+
             counter = counter + 2
 
         nEq = nHxs
@@ -942,7 +942,7 @@ class Type1924_TesPlugFlow:
 
         if nTes == 1:
             lines = lines + "CONSTANTS 3\n"
-            line = "TRoomStore=15 ! @userDefined\n"
+            line = "TRoomStore=15 ! \n"
             lines = lines + line
             line = "VStoreRef = 0.763\n"
             lines = lines + line
@@ -951,31 +951,25 @@ class Type1924_TesPlugFlow:
         line = "ratioTes%d = Vol_Tes%d / VStoreRef\n" % (nTes, nTes)
         lines = lines + line
 
-        for idPort in range(self.nMaxPorts):
-            if idPort <= nPorts - 1:
+        for idPort in range(nPorts):
+            line = self.getOnePortParConn(idPort, nTes, self.connectorsPort)
+            lines = lines + line
 
-                line = self.getOnePortParConn(idPort, nTes, self.connectorsPort)
-                lines = lines + line
+        for idHx in range(nHxs):
+            line = self.getOneHxParConnValues(nTes, idHx + 1, self.connectorsHx)
+            lines = lines + line
 
-        for idHx in range(self.nMaxHx):
-            if idHx <= nHxs - 1:
-                line = self.getOneHxParConnValues(nTes, idHx + 1, self.connectorsHx)
-                lines = lines + line
-
-        for idPort in range(self.nMaxPorts):
-            if idPort <= nPorts - 1:
-
-                line = self.getOnePortPar(idPort, nTes)
-                lines = lines + line
+        for idPort in range(nPorts):
+            line = self.getOnePortPar(idPort, nTes)
+            lines = lines + line
 
         lines = lines + "********** HEAT EXCHANGER CONSTANTS*******\n"
         lines = lines + "CONSTANTS 1\n"
         lines = lines + "nHxUsed_Tes%d=%d \n" % (nTes, nHxs)
 
-        for idHx in range(self.nMaxHx):
-            if idHx <= nHxs - 1:
-                line = self.getOneHxParValues(nTes, idHx + 1)
-                lines = lines + line
+        for idHx in range(nHxs):
+            line = self.getOneHxParValues(nTes, idHx + 1)
+            lines = lines + line
 
         lines = lines + self.getSensorPositionValues(nTes)
         lines = lines + self.getHeighAvgSensorParValues(nTes)
@@ -984,7 +978,5 @@ class Type1924_TesPlugFlow:
         lines = lines + self.getInsulationPlateParValues(nTes)
         lines = lines + self.getParameters(self.inputs)
 
-        nameWithPath = "%s\%s.%s" % (path, (tankName), self.extension)
-        outfile = open(nameWithPath, "w")
-        outfile.writelines(lines)
-        outfile.close()
+        outputFilePath = _pl.Path(path) / f"{tankName}.{self.extension}"
+        outputFilePath.write_text(lines)
